/* WARNING: This file is generated!
 * Do not edit this file, but edit /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_es.xml instead and run
 * python configgen.py -wiz /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_es.xml to regenerate this file!
 */
#include "configdoc.h"
#include "docintf.h"

void addConfigDocs_es(DocIntf *doc)
{
  doc->setHeader(
              "Este archivo describe la configuración que utilizará el sistema de\n"
              "documentación Doxygen (www.doxygen.org) para un proyecto.\n"
              "\n"
              "Todo el texto que sigue a una doble almohadilla (##) se considera un\n"
              "comentario y se coloca delante de la etiqueta a la que precede.\n"
              "\n"
              "Todo el texto que sigue a una única almohadilla (#) se considera un\n"
              "comentario y será ignorado. El formato es:\n"
              "TAG = value [value, ...]\n"
              "Para las listas, los elementos también se pueden añadir usando:\n"
              "TAG += value [value, ...]\n"
              "Los valores que contienen espacios deben colocarse entre comillas (\" \").\n"
              "\n"
              "Nota:\n"
              "\n"
              "Use Doxygen para comparar el archivo de configuración utilizado con el\n"
              "archivo de configuración de plantilla:\n"
              "doxygen -x [configFile]\n"
              "Use Doxygen para comparar el archivo de configuración utilizado con el\n"
              "archivo de configuración de plantilla sin reemplazar las variables de entorno\n"
              "o las variables de reemplazo de tipo CMake:\n"
              "doxygen -x_noenv [configFile]"
             );
  doc->add(
              "DOXYFILE_ENCODING",
              "Esta etiqueta especifica la codificación de todos los caracteres en el archivo\n"
              "de configuración que sigue. El valor predeterminado es UTF-8, que también es\n"
              "la codificación para todo el texto antes de la primera aparición de esta\n"
              "etiqueta. Doxygen usa libiconv (o iconv incorporado en libc) para la\n"
              "transcodificación. Ver https://www.gnu.org/software/libiconv/ para la lista de\n"
              "posibles codificaciones.\n"
              "El valor predeterminado es: UTF-8."
          );
  doc->add(
              "PROJECT_NAME",
              "La etiqueta PROJECT_NAME es una sola palabra (o una secuencia de palabras\n"
              "rodeadas de comillas dobles, a menos que esté usando Doxywizard) que debe\n"
              "identificar el proyecto para el cual se genera la documentación. Este nombre\n"
              "se usa en el título de la mayoría de las páginas generadas y en algunos otros\n"
              "lugares.\n"
              "El valor predeterminado es: My Project."
          );
  doc->add(
              "PROJECT_NUMBER",
              "La etiqueta PROJECT_NUMBER se puede usar para ingresar un número de proyecto o\n"
              "revisión. Esto puede ser útil para archivar la documentación generada o si se\n"
              "usa algún sistema de control de versiones."
          );
  doc->add(
              "PROJECT_BRIEF",
              "Usando la etiqueta PROJECT_BRIEF se puede proporcionar una descripción\n"
              "opcional de una línea para un proyecto que aparece en la parte superior de\n"
              "cada página y debe dar a los espectadores una idea rápida sobre el propósito\n"
              "del proyecto. Mantenga la descripción corta."
          );
  doc->add(
              "PROJECT_LOGO",
              "Con la etiqueta PROJECT_LOGO se puede especificar un logotipo o icono que se\n"
              "incluye en la documentación. La altura máxima del logotipo no debe exceder los\n"
              "55 píxeles y el ancho máximo no debe exceder los 200 píxeles. Doxygen copiará\n"
              "el logotipo en el directorio de salida."
          );
  doc->add(
              "PROJECT_ICON",
              "Con la etiqueta PROJECT_ICON se puede especificar un icono que se incluye en\n"
              "las pestañas cuando se muestra el documento HTML. Doxygen copiará el logotipo\n"
              "en el directorio de salida."
          );
  doc->add(
              "OUTPUT_DIRECTORY",
              "La etiqueta OUTPUT_DIRECTORY se usa para especificar la ruta (relativa o\n"
              "absoluta) donde se escribirá la documentación generada. Si se ingresa una ruta\n"
              "relativa, es relativa a la ubicación desde donde se inició Doxygen. Si se deja\n"
              "vacío, se usará el directorio actual."
          );
  doc->add(
              "CREATE_SUBDIRS",
              "Si la etiqueta CREATE_SUBDIRS está configurada en YES, Doxygen creará hasta\n"
              "4096 subdirectorios (en 2 niveles) bajo el directorio de salida de cada\n"
              "formato de salida y distribuirá los archivos generados en estos directorios.\n"
              "Habilitar esta opción puede ser útil cuando se alimenta a Doxygen con una gran\n"
              "cantidad de archivos fuente, donde colocar todos los archivos generados en el\n"
              "mismo directorio causaría problemas de rendimiento para el sistema de\n"
              "archivos. Ajuste CREATE_SUBDIRS_LEVEL para controlar el número de\n"
              "subdirectorios.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "CREATE_SUBDIRS_LEVEL",
              "Controla el número de subdirectorios que se crean cuando la etiqueta\n"
              "CREATE_SUBDIRS está configurada en YES. El nivel 0 representa 16 directorios,\n"
              "y cada aumento de nivel duplica el número de directorios, resultando en 4096\n"
              "directorios en el nivel 8, que es el valor predeterminado y también el valor\n"
              "máximo. Los subdirectorios están organizados en 2 niveles, donde el primer\n"
              "nivel siempre tiene un número fijo de 16 directorios.\n"
              "Valor mínimo: 0, valor máximo: 8, valor predeterminado: 8.\n"
              "Esta etiqueta requiere que la etiqueta CREATE_SUBDIRS esté establecida en YES."
          );
  doc->add(
              "ALLOW_UNICODE_NAMES",
              "Si la etiqueta ALLOW_UNICODE_NAMES está configurada en YES, Doxygen permitirá\n"
              "caracteres no ASCII en los nombres de los archivos generados. Si se configura\n"
              "en NO, los caracteres no ASCII serán escapados, por ejemplo _xE3_x81_x84 para\n"
              "Unicode U+3044.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "OUTPUT_LANGUAGE",
              "La etiqueta OUTPUT_LANGUAGE se usa para especificar el idioma en el que se\n"
              "escribe toda la documentación generada por Doxygen. Doxygen usará esta\n"
              "información para generar toda la salida constante en el idioma apropiado.\n"
              "Los valores posibles son:Afrikaans, Arabic, Armenian, Brazilian, Bulgarian,\n"
              "Catalan, Chinese, Chinese-Traditional, Croatian, Czech, Danish, Dutch, English\n"
              "(Estados Unidos), Esperanto, Farsi (Persa), Finnish, French, German, Greek,\n"
              "Hindi, Hungarian, Indonesian, Italian, Japanese, Japanese-en (Japonés con\n"
              "mensajes en inglés), Korean, Korean-en (Coreano con mensajes en inglés),\n"
              "Latvian, Lithuanian, Macedonian, Norwegian, Persian (Farsi), Polish,\n"
              "Portuguese, Romanian, Russian, Serbian, Serbian-Cyrillic, Slovak, Slovene,\n"
              "Spanish, Swedish, Turkish, UkrainianyVietnamese.\n"
              "El valor predeterminado es: English."
          );
  doc->add(
              "BRIEF_MEMBER_DESC",
              "Si la etiqueta BRIEF_MEMBER_DESC está configurada en YES, Doxygen incluirá\n"
              "descripciones breves de los miembros después de los miembros que se enumeran\n"
              "en la documentación de archivos y clases (similar a Javadoc). Configure en NO\n"
              "para desactivar esto.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "REPEAT_BRIEF",
              "Si la etiqueta REPEAT_BRIEF está configurada en YES, Doxygen antepondrá la\n"
              "descripción breve de un miembro o función antes de la descripción detallada.\n"
              "\n"
              "Nota: Si tanto HIDE_UNDOC_MEMBERS como BRIEF_MEMBER_DESC están configurados en\n"
              "NO, las descripciones breves se suprimirán por completo.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "ABBREVIATE_BRIEF",
              "Esta etiqueta implementa un abreviador de descripción breve casi inteligente\n"
              "que se usa para formar el texto en varias listas. Cada cadena en esta lista,\n"
              "si se encuentra como el texto inicial de una descripción breve, se eliminará\n"
              "del texto, y el resultado después de procesar toda la lista se usará como el\n"
              "texto anotado. De lo contrario, se usará la descripción breve como se\n"
              "especificó. Si se deja vacío, se usarán los siguientes valores ($name se\n"
              "reemplaza automáticamente por el nombre de la entidad):The $name class, The\n"
              "$name widget, The $name file, is, provides, specifies, contains, represents,\n"
              "a, anythe."
          );
  doc->add(
              "ALWAYS_DETAILED_SEC",
              "Si las etiquetas ALWAYS_DETAILED_SEC y REPEAT_BRIEF están configuradas en YES,\n"
              "Doxygen generará una sección detallada incluso si solo hay una descripción\n"
              "breve.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "INLINE_INHERITED_MEMB",
              "Si la etiqueta INLINE_INHERITED_MEMB está configurada en YES, Doxygen mostrará\n"
              "todos los miembros heredados de una clase en la documentación de esa clase\n"
              "como si esos miembros fueran miembros normales de la clase. Los constructores,\n"
              "destructores y operadores de asignación de las clases base no se mostrarán.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "FULL_PATH_NAMES",
              "Si la etiqueta FULL_PATH_NAMES está configurada en YES, Doxygen antepondrá la\n"
              "ruta completa antes de los nombres de archivo en la lista de archivos y en los\n"
              "archivos de encabezado. Si se configura en NO, se usará la ruta más corta que\n"
              "haga que los nombres de archivo sean únicos.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "STRIP_FROM_PATH",
              "La etiqueta STRIP_FROM_PATH se puede usar para eliminar una parte definida por\n"
              "el usuario de la ruta. La eliminación solo se hace si una de las cadenas\n"
              "especificadas coincide con la parte izquierda de la ruta. La etiqueta se puede\n"
              "usar para mostrar rutas relativas en la lista de archivos. Si se deja vacío,\n"
              "el directorio desde donde se ejecuta Doxygen se usa como la ruta a eliminar.\n"
              "\n"
              "Tenga en cuenta que puede especificar rutas absolutas aquí, pero también rutas\n"
              "relativas, que serán relativas al directorio donde se inició Doxygen.\n"
              "Esta etiqueta requiere que la etiqueta FULL_PATH_NAMES esté establecida en\n"
              "YES."
          );
  doc->add(
              "STRIP_FROM_INC_PATH",
              "La etiqueta STRIP_FROM_INC_PATH se puede usar para eliminar una parte definida\n"
              "por el usuario de la ruta mencionada en la documentación de una clase, que le\n"
              "dice al lector que archivo de encabezado incluir para usar una clase. Si se\n"
              "deja vacío, solo se usará el nombre del archivo de encabezado que contiene la\n"
              "definición de la clase. De lo contrario, se debe especificar la lista de rutas\n"
              "de inclusión que normalmente se pasan al compilador usando la bandera -I."
          );
  doc->add(
              "SHORT_NAMES",
              "Si la etiqueta SHORT_NAMES está configurada en YES, Doxygen generará nombres\n"
              "de archivo cortos (pero no únicos). Esto puede ser útil si su sistema de\n"
              "archivos no soporta nombres largos, como DOS, Mac o CD-ROM.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "JAVADOC_AUTOBRIEF",
              "Si la etiqueta JAVADOC_AUTOBRIEF está configurada en YES, Doxygen interpretará\n"
              "la primera línea (hasta el primer punto, signo de interrogación o signo de\n"
              "exclamación) de un comentario estilo Javadoc como la descripción breve. Si se\n"
              "configura en NO, el estilo Javadoc se comportara como comentarios de estilo Qt\n"
              "normales (por lo que se requiere un comando @brief explícito para una\n"
              "descripción breve).\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "JAVADOC_BANNER",
              "Si la etiqueta JAVADOC_BANNER está configurada en YES, Doxygen interpretará\n"
              "una línea como\n"
              "/***************\n"
              "como el comienzo de un banner de comentario estilo Javadoc. Si se configura\n"
              "en NO, el estilo Javadoc se comportara como comentarios normales y no será\n"
              "interpretado por Doxygen.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "QT_AUTOBRIEF",
              "Si la etiqueta QT_AUTOBRIEF está configurada en YES, Doxygen interpretará la\n"
              "primera línea (hasta el primer punto, signo de interrogación o signo de\n"
              "exclamación) de un comentario estilo Qt como la descripción breve. Si se\n"
              "configura en NO, el estilo Qt se comportara como comentarios estilo Qt\n"
              "normales (por lo que se requiere un comando \\brief explícito para una\n"
              "descripción breve).\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "MULTILINE_CPP_IS_BRIEF",
              "La etiqueta MULTILINE_CPP_IS_BRIEF se puede configurar en YES para hacer que\n"
              "Doxygen trate un bloque de comentario especial de C++ multilinea (es decir, un\n"
              "bloque de comentarios //! o ///) como una descripción breve. Este era el\n"
              "comportamiento predeterminado anteriormente. El nuevo valor predeterminado es\n"
              "tratar un bloque de comentarios de C++ multilinea como una descripción\n"
              "detallada. Configure esta etiqueta en YES si prefiere el comportamiento\n"
              "anterior.\n"
              "\n"
              "Tenga en cuenta que configurar esta etiqueta en YES también significa que los\n"
              "comentarios de Rational Rose ya no serán reconocidos.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "PYTHON_DOCSTRING",
              "Por defecto, los docstrings de Python se muestran como texto preformateado y\n"
              "no se pueden usar los comandos especiales de Doxygen. Al configurar\n"
              "PYTHON_DOCSTRING en NO, se pueden usar los comandos especiales de Doxygen y el\n"
              "contenido de los bloques de documentación de docstrings se muestra como\n"
              "documentación de Doxygen.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "INHERIT_DOCS",
              "Si la etiqueta INHERIT_DOCS está configurada en YES, un miembro no documentado\n"
              "heredara la documentación de cualquier miembro documentado que reimplemente.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "SEPARATE_MEMBER_PAGES",
              "Si la etiqueta SEPARATE_MEMBER_PAGES está configurada en YES, Doxygen generará\n"
              "una página separada para cada miembro. Si se configura en NO, la documentación\n"
              "de todos los miembros de un compuesto (clase, archivo, espacio de nombres) se\n"
              "combinará en un solo documento.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "TAB_SIZE",
              "La etiqueta TAB_SIZE se puede usar para establecer el número de espacios en\n"
              "una tabulación. Doxygen usa este valor para reemplazar las tabulaciones por\n"
              "espacios en los fragmentos de código.\n"
              "Valor mínimo: 1, valor máximo: 16, valor predeterminado: 4."
          );
  doc->add(
              "ALIASES",
              "Esta etiqueta se puede usar para especificar varios alias que actuen como\n"
              "comandos en la documentación. Un alias tiene la forma:\n"
              "nombre=valor\n"
              "Por ejemplo, agregar\n"
              "\"sideeffect=@par Efectos secundarios:^^\"\n"
              "le permitirá colocar el comando \\sideeffect (o @sideeffect) en la\n"
              "documentación, lo que resultará en un párrafo definido por el usuario con el\n"
              "encabezado \"Efectos secundarios:\". Tenga en cuenta que no puede poner \\n en el\n"
              "valor de un alias para insertar un salto de línea (en la salida resultante).\n"
              "Puede poner ^^ en el valor de un alias para insertar un salto de línea como si\n"
              "hubiera un salto de línea físico en el archivo original.Cuando necesites usar\n"
              "literalmente {, } o , en el valor de un alias, debes escaparlos con una barra\n"
              "invertida (\\). Esto puede generar conflictos con los comandos \\{ y \\}. Para\n"
              "estos últimos, se recomienda usar la versión @{ y @} o usar una doble\n"
              "secuencia de escape (\\\\{ y \\\\})."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_FOR_C",
              "Configure la etiqueta OPTIMIZE_OUTPUT_FOR_C en YES si su proyecto consiste\n"
              "solo en fuentes C. Doxygen generará una salida más adaptada a C. Por ejemplo,\n"
              "algunos de los nombres usados serán diferentes. La lista de todos los miembros\n"
              "se omitirá, etc.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_JAVA",
              "Configure la etiqueta OPTIMIZE_OUTPUT_JAVA en YES si su proyecto consiste solo\n"
              "en fuentes Java o Python. Doxygen generará una salida más adaptada a ese\n"
              "lenguaje. Por ejemplo, los espacios de nombres se presentarán como paquetes,\n"
              "los ámbitos calificados se verán diferentes, etc.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "OPTIMIZE_FOR_FORTRAN",
              "Configure la etiqueta OPTIMIZE_FOR_FORTRAN en YES si su proyecto consiste en\n"
              "fuentes Fortran. Doxygen generará una salida adaptada a Fortran.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_VHDL",
              "Configure la etiqueta OPTIMIZE_OUTPUT_VHDL en YES si su proyecto consiste en\n"
              "fuentes VHDL. Doxygen generará una salida adaptada a VHDL.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_SLICE",
              "Configure la etiqueta OPTIMIZE_OUTPUT_SLICE en YES si su proyecto consiste\n"
              "solo en fuentes Slice. Doxygen generará una salida más adaptada a ese\n"
              "lenguaje. Por ejemplo, los espacios de nombres se presentarán como módulos,\n"
              "los tipos se agruparán en más grupos, etc.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "EXTENSION_MAPPING",
              "Doxygen selecciona el analizador a usar basándose en la extensión del archivo\n"
              "a analizar. Con esta etiqueta puede asignar un analizador para usar con una\n"
              "extensión dada. Doxygen tiene un mapeo incorporado, pero puede anularlo o\n"
              "extenderlo con esta etiqueta. El formato es ext=language, donde ext es una\n"
              "extensión de archivo y language es uno de los analizadores soportados por\n"
              "Doxygen: IDL, Java, JavaScript, Csharp (C#), C, C++, Lex, D, PHP, md\n"
              "(Markdown), Objective-C, Python, Slice, VHDL, Fortran (Fortran de formato\n"
              "fijo: FortranFixed, Fortran de formato libre: FortranFree, Fortran de formato\n"
              "desconocido: Fortran. En este último caso, el analizador intentará adivinar si\n"
              "el código es de formato fijo o libre, que es el valor predeterminado para\n"
              "archivos de tipo Fortran). Por ejemplo, para hacer que Doxygen trate los\n"
              "archivos .inc como archivos Fortran (el valor predeterminado es PHP) y los\n"
              "archivos .f como C (el valor predeterminado es Fortran), use: inc=Fortran f=C.\n"
              "\n"
              "Nota: Para archivos sin extensión, puede usar no_extension como comodín.\n"
              "\n"
              "Nota: Cuando se especifica no_extension, también debe agregar * a\n"
              "FILE_PATTERNS.\n"
              "\n"
              "Nota: Para extensiones personalizadas, también debe configurar FILE_PATTERNS,\n"
              "de lo contrario los archivos no serán leidos por Doxygen.\n"
              "\n"
              "Nota: Vea también la lista de mapeos de extensiones de archivo\n"
              "predeterminados."
          );
  doc->add(
              "MARKDOWN_SUPPORT",
              "Si la etiqueta MARKDOWN_SUPPORT está habilitada, Doxygen preprocesará todos\n"
              "los comentarios de acuerdo con el formato Markdown, lo que permite una\n"
              "documentación más legible. Vea https://daringfireball.net/projects/markdown/\n"
              "para detalles. La salida del procesamiento de Markdown es procesada\n"
              "posteriormente por Doxygen, por lo que puede mezclar comandos de Doxygen, HTML\n"
              "y XML con formato Markdown. Deshabilite esto solo si tiene problemas con la\n"
              "compatibilidad hacia atras.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "MARKDOWN_STRICT",
              "Si la etiqueta MARKDOWN_STRICT está habilitada, Doxygen tratará el texto en\n"
              "los comentarios como Markdown formateado también en casos donde el formato de\n"
              "marcado nativo de Doxygen entra en conflicto con el de Markdown. Esto solo es\n"
              "relevante en casos donde se usan acentos graves. El estilo de marcado nativo\n"
              "de Doxygen permite que una comilla simple termine un fragmento de texto que\n"
              "comenzo con un acento grave y luego tratarlo como un fragmento de texto\n"
              "citado, mientras que en Markdown tal fragmento de texto se trata como literal\n"
              "y solo termina cuando se encuentra un segundo acento grave coincidente.\n"
              "Además, el formato de marcado nativo de Doxygen requiere que las comillas\n"
              "dobles se escapen cuando aparecen en una sección de acentos graves, mientras\n"
              "que esto no es necesario para Markdown.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta MARKDOWN_SUPPORT esté establecida en\n"
              "YES."
          );
  doc->add(
              "TOC_INCLUDE_HEADINGS",
              "Cuando la etiqueta TOC_INCLUDE_HEADINGS está configurada en un valor no nulo,\n"
              "todos los encabezados hasta ese nivel se incluyen automáticamente en la tabla\n"
              "de contenidos, incluso si no tienen un atributo id.\n"
              "Nota: Esta función actualmente se aplica solo a los encabezados de Markdown.\n"
              "Valor mínimo: 0, valor máximo: 99, valor predeterminado: 6.\n"
              "Esta etiqueta requiere que la etiqueta MARKDOWN_SUPPORT esté establecida en\n"
              "YES."
          );
  doc->add(
              "MARKDOWN_ID_STYLE",
              "La etiqueta MARKDOWN_ID_STYLE se puede usar para especificar el algoritmo\n"
              "utilizado para generar identificadores para los encabezados de Markdown. Nota:\n"
              "Cada identificador es único.\n"
              "Los valores posibles son:DOXYGEN usar una cadena 'autotoc_md' fija seguida de\n"
              "un número de secuencia comenzando en 0yGITHUB usar la versión en minúsculas\n"
              "del título con cualquier espacio en blanco reemplazado por '-' y caracteres de\n"
              "puntuación eliminados.\n"
              "El valor predeterminado es: DOXYGEN.\n"
              "Esta etiqueta requiere que la etiqueta MARKDOWN_SUPPORT esté establecida en\n"
              "YES."
          );
  doc->add(
              "AUTOLINK_SUPPORT",
              "Si está habilitado, Doxygen intentará vincular palabras que correspondan a una\n"
              "clase o espacio de nombres documentado con la documentación correspondiente.\n"
              "Esto se puede evitar en casos individuales colocando un símbolo % antes de la\n"
              "palabra, o globalmente configurando AUTOLINK_SUPPORT en NO. Las palabras\n"
              "listadas en la etiqueta AUTOLINK_IGNORE_WORDS serán excluidas de la\n"
              "vinculación automática.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "AUTOLINK_IGNORE_WORDS",
              "Esta etiqueta especifica una lista de palabras que, cuando coinciden con el\n"
              "comienzo de una palabra en la documentación, suprimirán la generación\n"
              "automática de enlaces cuando esta está habilitada por AUTOLINK_SUPPORT. Esta\n"
              "lista no afecta los enlaces creados explícitamente con # o los comandos \\link\n"
              "o \\ref.\n"
              "Esta etiqueta requiere que la etiqueta AUTOLINK_SUPPORT esté establecida en\n"
              "YES."
          );
  doc->add(
              "BUILTIN_STL_SUPPORT",
              "Si usa clases STL (es decir, std::string, std::vector, etc.), pero no incluye\n"
              "el código fuente (archivo de etiquetas) de la STL como entrada, debe\n"
              "configurar esta etiqueta en YES para que Doxygen pueda hacer coincidir\n"
              "declaraciones y definiciones de funciones con argumentos que contienen clases\n"
              "STL (por ejemplo, func(std::string); versus func(std::string) {}). Esto\n"
              "también hace que los diagramas de herencia y colaboración que involucran\n"
              "clases STL sean más completos y precisos.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "CPP_CLI_SUPPORT",
              "Si usa el lenguaje C++/CLI de Microsoft, debe configurar esta opción en YES\n"
              "para habilitar el soporte de análisis.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "SIP_SUPPORT",
              "Configure la etiqueta SIP_SUPPORT en YES si su proyecto consiste solo en\n"
              "fuentes [sip]. Doxygen las analizará como C++ normal pero asumirá que todas\n"
              "las clases usan herencia pública en lugar de privada cuando no se presenta\n"
              "ninguna palabra clave de protección explícita.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "IDL_PROPERTY_SUPPORT",
              "Para el IDL de Microsoft, existen los atributos propget y propput para indicar\n"
              "métodos getter y setter para una propiedad. Configurar esta opción en YES hará\n"
              "que Doxygen reemplace los métodos get y set en la documentación con la\n"
              "propiedad. Esto solo funciona si los métodos realmente obtienen o establecen\n"
              "un tipo simple. Si este no es el caso o si desea mostrar los métodos de todos\n"
              "modos, debe configurar esta opción en NO.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "DISTRIBUTE_GROUP_DOC",
              "Si se usa la agrupación de miembros en la documentación y la etiqueta\n"
              "DISTRIBUTE_GROUP_DOC está configurada en YES, Doxygen reutilizara la\n"
              "documentación del primer miembro del grupo para los otros miembros del grupo\n"
              "(si los hay). Por defecto, todos los miembros de un grupo deben estar\n"
              "documentados explícitamente.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "GROUP_NESTED_COMPOUNDS",
              "Cuando una estructura o clase se agrega a un grupo y esta opción está\n"
              "habilitada, todas las clases o estructuras anidadas también se agregarán al\n"
              "mismo grupo. Por defecto, esta opción está deshabilitada y uno debe agregar\n"
              "entidades anidadas explícitamente a través de \\ingroup.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "SUBGROUPING",
              "Configure la etiqueta SUBGROUPING en YES para permitir que los grupos de\n"
              "miembros de clase del mismo tipo (por ejemplo, un grupo de funciones públicas)\n"
              "se coloquen como un subgrupo de ese tipo (por ejemplo, bajo la sección\n"
              "Funciones Públicas). Configúrelo en NO para evitar la subagrupación.\n"
              "Alternativamente, esto se puede hacer por clase usando el comando\n"
              "\\nosubgrouping.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "INLINE_GROUPED_CLASSES",
              "Si la etiqueta INLINE_GROUPED_CLASSES está configurada en YES, las clases,\n"
              "estructuras y uniones se mostrarán dentro del grupo en el que están contenidas\n"
              "(por ejemplo, con \\ingroup) en lugar de en una página separada (para HTML y\n"
              "páginas de manual) o en una sección (para LaTeX y RTF).\n"
              "\n"
              "Tenga en cuenta que esta función no funciona en combinación con\n"
              "SEPARATE_MEMBER_PAGES.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "INLINE_SIMPLE_STRUCTS",
              "Si la etiqueta INLINE_SIMPLE_STRUCTS está configurada en YES, las estructuras,\n"
              "clases y uniones con solo campos de datos públicos o campos typedef simples se\n"
              "mostrarán en línea en la documentación del ámbito en el que están definidas\n"
              "(es decir, documentación de archivo, espacio de nombres o grupo), siempre que\n"
              "dicho ámbito este documentado. Si se configura en NO, las estructuras, clases\n"
              "y uniones se mostrarán en una página separada (para HTML y páginas de manual)\n"
              "o en una sección (para LaTeX y RTF).\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "TYPEDEF_HIDES_STRUCT",
              "Cuando la etiqueta TYPEDEF_HIDES_STRUCT está habilitada, una definición de\n"
              "tipo de una estructura, unión o enumeración se documenta como estructura,\n"
              "unión o enumeración con el nombre de la definición de tipo. Así, typedef\n"
              "struct TypeS {} TypeT aparecerá en la documentación como una estructura con\n"
              "nombre TypeT. Cuando está deshabilitado, la definición de tipo aparecerá como\n"
              "un miembro de un archivo, espacio de nombres o clase. Y la estructura se\n"
              "llamará TypeS. Esto puede ser típicamente útil para código C en caso de que la\n"
              "convención de codificación dicte que todos los tipos compuestos se definen con\n"
              "typedef y solo se hace referencia a la definición de tipo, nunca al nombre de\n"
              "la etiqueta.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "LOOKUP_CACHE_SIZE",
              "El tamaño del cache de búsqueda de símbolos se puede configurar con\n"
              "LOOKUP_CACHE_SIZE. Este cache se usa para resolver símbolos por su nombre y\n"
              "alcance. Dado que este puede ser un proceso costoso y el mismo símbolo aparece\n"
              "a menudo múltiples veces en el código, Doxygen mantiene un cache de símbolos\n"
              "pre-resueltos. Si el cache es demasiado pequeño, Doxygen será más lento. Si el\n"
              "cache es demasiado grande, se desperdicia memoria. El tamaño del cache viene\n"
              "dado por esta formula: 2^(16+LOOKUP_CACHE_SIZE). El rango válido es 0..9, el\n"
              "predeterminado es 0, que corresponde a un tamaño de cache de 2^16=65536\n"
              "símbolos. Al final de una ejecución, Doxygen informará el uso del cache y\n"
              "sugerirá el tamaño de cache óptimo desde el punto de vista de la velocidad.\n"
              "Valor mínimo: 0, valor máximo: 9, valor predeterminado: 0."
          );
  doc->add(
              "NUM_PROC_THREADS",
              "La etiqueta NUM_PROC_THREADS especifica el número de subprocesos que Doxygen\n"
              "puede usar durante el procesamiento. Cuando se configura en 0, Doxygen lo\n"
              "basará en el número de núcleos disponibles en el sistema. Puede configurarlo\n"
              "explícitamente en un valor mayor que 0 para obtener más control sobre el\n"
              "equilibrio entre la carga de la CPU y la velocidad de procesamiento. Por el\n"
              "momento, solo el procesamiento de entrada se puede realizar con múltiples\n"
              "subprocesos. Dado que esta es todavía una característica experimental, el\n"
              "valor predeterminado se establece en 1, lo que deshabilita efectivamente el\n"
              "procesamiento paralelo. Por favor, informe cualquier problema que encuentre.\n"
              "La generación paralela de grafos dot se controla mediante la configuración\n"
              "DOT_NUM_THREADS.\n"
              "Valor mínimo: 0, valor máximo: 512, valor predeterminado: 1."
          );
  doc->add(
              "TIMESTAMP",
              "Si la etiqueta TIMESTAMP está configurada diferente de NO, cada página\n"
              "generada contendrá la fecha o fecha y hora cuando se genero la página.\n"
              "Configurar esto en NO puede ayudar al comparar la salida de múltiples\n"
              "ejecuciones.\n"
              "Los valores posibles son:YES, NO, DATETIMEyDATE.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "EXTRACT_ALL",
              "Si la etiqueta EXTRACT_ALL está configurada en YES, Doxygen asumira que todas\n"
              "las entidades en la documentación están documentadas, incluso si no habia\n"
              "documentación disponible. Los miembros privados de clase y los miembros\n"
              "estáticos de archivo se ocultarán a menos que las etiquetas EXTRACT_PRIVATE y\n"
              "EXTRACT_STATIC estén configuradas en YES.\n"
              "Nota: Esto también deshabilita las advertencias sobre miembros no documentados\n"
              "que normalmente se generan cuando WARNINGS está configurado en YES.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "EXTRACT_PRIVATE",
              "Si la etiqueta EXTRACT_PRIVATE está configurada en YES, todos los miembros\n"
              "privados de una clase se incluirán en la documentación.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "EXTRACT_PRIV_VIRTUAL",
              "Si la etiqueta EXTRACT_PRIV_VIRTUAL está configurada en YES, los métodos\n"
              "virtuales privados documentados de una clase se incluirán en la documentación.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "EXTRACT_PACKAGE",
              "Si la etiqueta EXTRACT_PACKAGE está configurada en YES, todos los miembros con\n"
              "alcance de visibilidad de paquete o interno se incluirán en la documentación.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "EXTRACT_STATIC",
              "Si la etiqueta EXTRACT_STATIC está configurada en YES, todos los miembros\n"
              "estáticos de un archivo se incluirán en la documentación.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "EXTRACT_LOCAL_CLASSES",
              "Si la etiqueta EXTRACT_LOCAL_CLASSES está configurada en YES, las clases\n"
              "definidas localmente en archivos fuente (y estructuras) se incluirán en la\n"
              "documentación. Si se configura en NO, solo se incluirán las clases definidas\n"
              "en archivos de encabezado. No tiene efecto para las fuentes Java.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "EXTRACT_LOCAL_METHODS",
              "Esta bandera solo es útil para código Objective-C. Si se configura en YES, los\n"
              "métodos locales definidos en la sección de implementación pero no en la\n"
              "interfaz se incluirán en la documentación. Si se configura en NO, solo se\n"
              "incluirán los métodos en la interfaz.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "EXTRACT_ANON_NSPACES",
              "Si esta bandera está configurada en YES, los miembros de espacios de nombres\n"
              "anónimos serán extraidos y aparecerán en la documentación como un espacio de\n"
              "nombres llamado 'anonymous_namespace{file}', donde file se reemplaza por el\n"
              "nombre base del archivo que contiene el espacio de nombres anónimo. Por\n"
              "defecto, los espacios de nombres anónimos están ocultos.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "RESOLVE_UNNAMED_PARAMS",
              "Si esta bandera está configurada en YES, el nombre de un parámetro sin nombre\n"
              "en una declaración será determinado por la definición correspondiente. Por\n"
              "defecto, los parámetros sin nombre permanecen sin nombre en la salida.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "HIDE_UNDOC_MEMBERS",
              "Si la etiqueta HIDE_UNDOC_MEMBERS está configurada en YES, Doxygen ocultará\n"
              "todos los miembros no documentados dentro de clases o archivos documentados.\n"
              "Si se configura en NO, estos miembros se incluirán en las varias descripciones\n"
              "generales, pero no se generará ninguna sección de documentación. Esta opción\n"
              "no tiene efecto si EXTRACT_ALL está habilitada.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "HIDE_UNDOC_CLASSES",
              "Si la etiqueta HIDE_UNDOC_CLASSES está configurada en YES, Doxygen ocultará\n"
              "todas las clases no documentadas que normalmente serían visibles en la\n"
              "jerarquía de clases. Si se configura en NO, estas clases se incluirán en las\n"
              "varias descripciones generales. Esta opción también oculta los conceptos de\n"
              "C++ no documentados si está habilitada. Esta opción no tiene efecto si\n"
              "EXTRACT_ALL está habilitada.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "HIDE_UNDOC_NAMESPACES",
              "Si la etiqueta HIDE_UNDOC_NAMESPACES está configurada en YES, Doxygen ocultará\n"
              "todos los espacios de nombres no documentados que normalmente serían visibles\n"
              "en la jerarquía de espacios de nombres. Si se configura en NO, estos espacios\n"
              "de nombres se incluirán en las varias descripciones generales. Esta opción no\n"
              "tiene efecto si EXTRACT_ALL está habilitada.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "HIDE_FRIEND_COMPOUNDS",
              "Si la etiqueta HIDE_FRIEND_COMPOUNDS está configurada en YES, todas las\n"
              "declaraciones de amigo se ocultarán. Si se configura en NO, estas\n"
              "declaraciones se incluirán en la documentación.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "HIDE_IN_BODY_DOCS",
              "Si la etiqueta HIDE_IN_BODY_DOCS está configurada en YES, Doxygen ocultará los\n"
              "bloques de documentación encontrados dentro del cuerpo de una función. Si se\n"
              "configura en NO, estos bloques se agregarán al bloque de documentación\n"
              "detallado de la función.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "INTERNAL_DOCS",
              "La etiqueta INTERNAL_DOCS determina si la documentación escrita después de un\n"
              "comando \\internal se incluye. Si la etiqueta está configurada en NO, la\n"
              "documentación se excluye. Configúrela en YES para incluir la documentación\n"
              "interna.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "CASE_SENSE_NAMES",
              "Con la configuración correcta de la opción CASE_SENSE_NAMES, Doxygen podrá\n"
              "utilizar mejor las capacidades del sistema de archivos subyacente. En el caso\n"
              "de un sistema de archivos que distingue entre mayúsculas y minúsculas (es\n"
              "decir, admite archivos en el mismo directorio cuyos nombres difieren solo en\n"
              "mayúsculas/minúsculas), la opción debe configurarse en YES para manejar\n"
              "correctamente dichos archivos, si aparecen en la entrada. Para sistemas de\n"
              "archivos que no distinguen entre mayúsculas y minúsculas, la opción debe\n"
              "configurarse en NO para manejar archivos de salida para símbolos que difieren\n"
              "solo en mayúsculas/minúsculas. En Windows (incluyendo Cygwin) y macOS, los\n"
              "usuarios normalmente deben configurar esta opción en NO, mientras que en Linux\n"
              "u otras variantes de Unix, normalmente debe configurarse en YES.\n"
              "Los valores posibles son:SYSTEM, NOyYES.\n"
              "El valor predeterminado es: SYSTEM."
          );
  doc->add(
              "HIDE_SCOPE_NAMES",
              "Si la etiqueta HIDE_SCOPE_NAMES está configurada en NO, Doxygen mostrará\n"
              "miembros con sus ámbitos de clase y espacio de nombres completos en la\n"
              "documentación. Si se configura en YES, el ámbito se ocultará.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "HIDE_COMPOUND_REFERENCE",
              "Si la etiqueta HIDE_COMPOUND_REFERENCE está configurada en NO\n"
              "(predeterminado), Doxygen agregará texto adicional al título de una página,\n"
              "como Referencia de Clase. Si se configura en YES, la referencia de compuesto\n"
              "se ocultará.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "SHOW_HEADERFILE",
              "Si la etiqueta SHOW_HEADERFILE está configurada en YES, la documentación de\n"
              "una clase mostrará que archivo necesita ser incluido para usar la clase.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "SHOW_INCLUDE_FILES",
              "Si la etiqueta SHOW_INCLUDE_FILES está configurada en YES, Doxygen mostrará\n"
              "una lista de los archivos que son incluidos por un archivo en la documentación\n"
              "de ese archivo.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "SHOW_GROUPED_MEMB_INC",
              "Si la etiqueta SHOW_GROUPED_MEMB_INC está configurada en YES, Doxygen agregará\n"
              "para cada miembro agrupado una declaración de inclusión en la documentación,\n"
              "indicando al lector qué archivo debe incluir para poder usar el miembro.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "FORCE_LOCAL_INCLUDES",
              "Si la etiqueta FORCE_LOCAL_INCLUDES está configurada en YES, Doxygen listará\n"
              "los archivos de inclusión con comillas dobles en la documentación en lugar de\n"
              "con corchetes angulares.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "INLINE_INFO",
              "Si la etiqueta INLINE_INFO está configurada en YES, se insertará una etiqueta\n"
              "[inline] en la documentación para miembros inline.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "SORT_MEMBER_DOCS",
              "Si la etiqueta SORT_MEMBER_DOCS está configurada en YES, Doxygen ordenará la\n"
              "documentación (detallada) de los miembros de archivos y clases alfabeticamente\n"
              "por nombre de miembro. Si se configura en NO, los miembros aparecerán en orden\n"
              "de declaración.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "SORT_BRIEF_DOCS",
              "Si la etiqueta SORT_BRIEF_DOCS está configurada en YES, Doxygen ordenará las\n"
              "descripciones breves de los miembros de archivos, espacios de nombres y clases\n"
              "alfabeticamente por nombre de miembro. Si se configura en NO, los miembros\n"
              "aparecerán en orden de declaración. Tenga en cuenta que esto también influirá\n"
              "en el orden de las clases en la lista de clases.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "SORT_MEMBERS_CTORS_1ST",
              "Si la etiqueta SORT_MEMBERS_CTORS_1ST está configurada en YES, Doxygen\n"
              "ordenará la documentación (breve y detallada) de los miembros de clase para\n"
              "que los constructores y destructores se listen primero. Si se configura en NO,\n"
              "los constructores aparecerán en los órdenes respectivos definidos por\n"
              "SORT_BRIEF_DOCS y SORT_MEMBER_DOCS.\n"
              "Nota: Si SORT_BRIEF_DOCS está configurado en NO, esta opción se ignora para\n"
              "ordenar la documentación breve de miembros.\n"
              "Nota: Si SORT_MEMBER_DOCS está configurado en NO, esta opción se ignora para\n"
              "ordenar la documentación detallada de miembros.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "SORT_GROUP_NAMES",
              "Si la etiqueta SORT_GROUP_NAMES está configurada en YES, Doxygen ordenará la\n"
              "jerarquía de nombres de grupos en orden alfabético. Si se configura en NO, los\n"
              "nombres de grupos aparecerán en su orden definido.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "SORT_BY_SCOPE_NAME",
              "Si la etiqueta SORT_BY_SCOPE_NAME está configurada en YES, la lista de clases\n"
              "se ordenará por nombres completamente calificados, incluyendo espacios de\n"
              "nombres. Si se configura en NO, la lista de clases se ordenará solo por nombre\n"
              "de clase, sin incluir la parte del espacio de nombres.\n"
              "Nota: Esta opción no es muy útil si HIDE_SCOPE_NAMES está configurado en YES.\n"
              "Nota: Esta opción se aplica solo a la lista de clases, no a la lista\n"
              "alfabética.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "STRICT_PROTO_MATCHING",
              "Si la opción STRICT_PROTO_MATCHING está habilitada y Doxygen no puede hacer la\n"
              "resolución de tipo adecuada de todos los parámetros de una función, rechazará\n"
              "una coincidencia entre el prototipo y la implementación de una función miembro\n"
              "incluso si solo hay un candidato o es obvio que candidato elegir haciendo una\n"
              "simple coincidencia de cadena. Al deshabilitar STRICT_PROTO_MATCHING, Doxygen\n"
              "seguirá aceptando una coincidencia entre prototipo e implementación en tales\n"
              "casos.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "GENERATE_TODOLIST",
              "La etiqueta GENERATE_TODOLIST se puede usar para habilitar (YES) o\n"
              "deshabilitar (NO) la lista de tareas. Esta lista se crea colocando comandos\n"
              "\\todo en la documentación.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "GENERATE_TESTLIST",
              "La etiqueta GENERATE_TESTLIST se puede usar para habilitar (YES) o\n"
              "deshabilitar (NO) la lista de pruebas. Esta lista se crea colocando comandos\n"
              "\\test en la documentación.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "GENERATE_BUGLIST",
              "La etiqueta GENERATE_BUGLIST se puede usar para habilitar (YES) o deshabilitar\n"
              "(NO) la lista de errores. Esta lista se crea colocando comandos \\bug en la\n"
              "documentación.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "GENERATE_DEPRECATEDLIST",
              "La etiqueta GENERATE_DEPRECATEDLIST se puede usar para habilitar (YES) o\n"
              "deshabilitar (NO) la lista de obsoletos. Esta lista se crea colocando comandos\n"
              "\\deprecated en la documentación.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "GENERATE_REQUIREMENTS",
              "La etiqueta GENERATE_REQUIREMENTS se puede usar para habilitar (YES) o\n"
              "deshabilitar (NO) la página de requisitos. Cuando está habilitada, esta página\n"
              "se crea automáticamente cuando al menos un bloque de comentarios con un\n"
              "comando \\requirement aparece en la entrada.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "REQ_TRACEABILITY_INFO",
              "La etiqueta REQ_TRACEABILITY_INFO controla si se muestra información de\n"
              "trazabilidad en la página de requisitos (solo relevante cuando se usan bloques\n"
              "de comentarios \\requirement). La configuración NO deshabilitará la información\n"
              "de trazabilidad por completo. La configuración UNSATISFIED_ONLY mostrará una\n"
              "lista de requisitos a los que les falta una relación satisfies (a través del\n"
              "comando: \\satisfies). De manera similar, la configuración UNVERIFIED_ONLY\n"
              "mostrará una lista de requisitos a los que les falta una relación verifies (a\n"
              "través del comando: \\verifies). Configurar la etiqueta en YES (el valor\n"
              "predeterminado) mostrará ambas listas si corresponde.\n"
              "Los valores posibles son:YES, NO, UNSATISFIED_ONLYyUNVERIFIED_ONLY.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_REQUIREMENTS esté establecida\n"
              "en YES."
          );
  doc->add(
              "ENABLED_SECTIONS",
              "La etiqueta ENABLED_SECTIONS se puede usar para habilitar secciones de\n"
              "documentación condicional marcadas con bloques \\if <section_label> ... \\endif\n"
              "y \\cond <section_label> ... \\endcond."
          );
  doc->add(
              "MAX_INITIALIZER_LINES",
              "La etiqueta MAX_INITIALIZER_LINES determina el número máximo de líneas que\n"
              "puede tener el valor inicial de una variable o macro / define para aparecer en\n"
              "la documentación. Si el inicializador consiste en más líneas de las\n"
              "especificadas aquí, se ocultará. Use el valor 0 para ocultar los\n"
              "inicializadores por completo. La aparición del valor de variables individuales\n"
              "y macros / defines se puede controlar con el comando \\showinitializer o\n"
              "\\hideinitializer en la documentación, independientemente de esta\n"
              "configuración.\n"
              "Valor mínimo: 0, valor máximo: 10000, valor predeterminado: 30."
          );
  doc->add(
              "SHOW_USED_FILES",
              "Configure la etiqueta SHOW_USED_FILES en NO para deshabilitar la lista de\n"
              "archivos generados al final de la documentación de clases y estructuras. Si se\n"
              "configura en YES, la lista mencionará los archivos que se usaron para generar\n"
              "la documentación.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "SHOW_FILES",
              "Configure la etiqueta SHOW_FILES en NO para deshabilitar la generación de la\n"
              "página de Archivos. Esto eliminará la entrada de Archivos del Índice Rápido y\n"
              "de la Vista de Árbol de Carpetas (si está especificada).\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "SHOW_NAMESPACES",
              "Configure la etiqueta SHOW_NAMESPACES en NO para deshabilitar la generación de\n"
              "la página de Espacios de nombres. Esto eliminará la entrada de Espacios de\n"
              "nombres del Índice Rápido y de la Vista de Árbol de Carpetas (si está\n"
              "especificada).\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "FILE_VERSION_FILTER",
              "La etiqueta FILE_VERSION_FILTER se puede usar para especificar un programa o\n"
              "script que Doxygen debe invocar para obtener la versión actual de cada archivo\n"
              "(típicamente del sistema de control de versiones). Doxygen invocará el\n"
              "programa ejecutando (via popen()) el comando command input_file, donde command\n"
              "es el valor de la etiqueta FILE_VERSION_FILTER y input_file es el nombre de un\n"
              "archivo de entrada proporcionado por Doxygen. Lo que sea que el programa\n"
              "escriba en la salida estándar se usará como la versión del archivo.Para un\n"
              "ejemplo, vea la documentación."
          );
  doc->add(
              "LAYOUT_FILE",
              "La etiqueta LAYOUT_FILE se puede usar para especificar un archivo de diseño\n"
              "que Doxygen analizará. El archivo de diseño controla la estructura global de\n"
              "los archivos de salida generados de una manera independiente del formato de\n"
              "salida. Para crear el archivo de diseño que representa los valores\n"
              "predeterminados de Doxygen, ejecute Doxygen con la opción -l. Puede\n"
              "especificar opcionalmente un nombre de archivo después de la opción, si se\n"
              "omite, se usará DoxygenLayout.xml como nombre del archivo de diseño. Vea\n"
              "también la sección \"Changing the layout of pages\" para información.\n"
              "\n"
              "Tenga en cuenta que Doxygen analizará automáticamente un archivo llamado\n"
              "DoxygenLayout.xml si ejecuta Doxygen desde un directorio que contiene ese\n"
              "archivo, incluso si la etiqueta LAYOUT_FILE se deja vacía."
          );
  doc->add(
              "CITE_BIB_FILES",
              "La etiqueta CITE_BIB_FILES se puede usar para especificar uno o más archivos\n"
              "bib que contienen las definiciones de referencias. Esto debe ser una lista de\n"
              "archivos .bib. La extensión .bib se añadirá automáticamente si se omite. Esto\n"
              "requiere que la herramienta bibtex este instalada. Ver también\n"
              "https://en.wikipedia.org/wiki/BibTeX para más información. Para LaTeX el\n"
              "estilo de la bibliografia se puede controlar con LATEX_BIB_STYLE. Para usar\n"
              "esta función, necesita bibtex y perl en la ruta de búsqueda. Ver también \\cite\n"
              "para información sobre como crear referencias."
          );
  doc->add(
              "EXTERNAL_TOOL_PATH",
              "La etiqueta EXTERNAL_TOOL_PATH se puede usar para extender la ruta de búsqueda\n"
              "(variable de entorno PATH) para que las herramientas externas como latex y gs\n"
              "puedan ser encontradas.\n"
              "Nota: Los directorios especificados con EXTERNAL_TOOL_PATH se agregan antes de\n"
              "las rutas ya especificadas por la variable PATH y se agregan en el orden\n"
              "especificado.\n"
              "Nota: Esta opción es particularmente útil para macOS versión 14 (Sonoma) y\n"
              "superior cuando Doxygen se ejecuta desde Doxywizard, ya que en ese caso se\n"
              "ignoran todos los cambios personalizados en PATH. Un ejemplo típico en macOS\n"
              "es configurar\n"
              "EXTERNAL_TOOL_PATH = /Library/TeX/texbin /usr/local/bin\n"
              "Junto con la ruta predeterminada, la ruta de búsqueda completa que Doxygen\n"
              "usará al iniciar herramientas externas se convierte en\n"
              "PATH=/Library/TeX/texbin:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin"
          );
  doc->add(
              "QUIET",
              "La etiqueta QUIET se puede usar para activar/desactivar los mensajes generados\n"
              "a la salida estándar por Doxygen. Si QUIET está configurado en YES, esto\n"
              "implica que los mensajes están desactivados.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "WARNINGS",
              "La etiqueta WARNINGS se puede usar para activar/desactivar los mensajes de\n"
              "advertencia generados a la salida de error estándar (stderr) por Doxygen. Si\n"
              "WARNINGS está configurado en YES, esto implica que las advertencias están\n"
              "activadas.\n"
              "\n"
              "Consejo: Active las advertencias mientras escribe la documentación.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "WARN_IF_UNDOCUMENTED",
              "Si la etiqueta WARN_IF_UNDOCUMENTED está configurada en YES, Doxygen generará\n"
              "advertencias para miembros no documentados. Si EXTRACT_ALL está configurado en\n"
              "YES, esta bandera se deshabilitará automáticamente.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "WARN_IF_DOC_ERROR",
              "Si la etiqueta WARN_IF_DOC_ERROR está configurada en YES, Doxygen generará\n"
              "advertencias para errores potenciales en la documentación, como documentar\n"
              "algunos parámetros en una función documentada dos veces, o documentar\n"
              "parámetros que no existen o usar comandos de marcado incorrectamente.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "WARN_IF_INCOMPLETE_DOC",
              "Si WARN_IF_INCOMPLETE_DOC está configurado en YES, Doxygen advertirá sobre\n"
              "documentación incompleta de parámetros de función. Si se configura en NO,\n"
              "Doxygen aceptará que algunos parámetros no tengan documentación sin advertir.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "WARN_NO_PARAMDOC",
              "Esta opción WARN_NO_PARAMDOC se puede habilitar para obtener advertencias para\n"
              "funciones que están documentadas, pero no tienen documentación para sus\n"
              "parámetros o valor de retorno. Si se configura en NO, Doxygen solo advertirá\n"
              "sobre documentación de parámetros incorrecta, pero no sobre la ausencia de\n"
              "documentación. Si EXTRACT_ALL está configurado en YES, esta bandera se\n"
              "deshabilitará automáticamente. Vea también WARN_IF_INCOMPLETE_DOC\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "WARN_IF_UNDOC_ENUM_VAL",
              "Si la opción WARN_IF_UNDOC_ENUM_VAL está configurada en YES, Doxygen advertirá\n"
              "sobre valores de enumeración no documentados. Si se configura en NO, Doxygen\n"
              "aceptará valores de enumeración no documentados. Si EXTRACT_ALL está\n"
              "configurado en YES, esta bandera se deshabilitará automáticamente.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "WARN_LAYOUT_FILE",
              "Si la opción WARN_LAYOUT_FILE está configurada en YES, Doxygen advertirá sobre\n"
              "problemas encontrados al analizar el archivo de diseño definido por el\n"
              "usuario, como elementos faltantes o incorrectos. Vea también LAYOUT_FILE para\n"
              "detalles. Si se configura en NO, los problemas con el archivo de diseño se\n"
              "suprimirán.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "WARN_AS_ERROR",
              "Si la etiqueta WARN_AS_ERROR está configurada en YES, Doxygen se detendrá\n"
              "inmediatamente cuando encuentre una advertencia. Si la etiqueta WARN_AS_ERROR\n"
              "está configurada en FAIL_ON_WARNINGS, Doxygen continuara ejecutandose como si\n"
              "la etiqueta WARN_AS_ERROR estuviera configurada en NO, pero al final del\n"
              "proceso Doxygen regresará con un estado distinto de cero. Si la etiqueta\n"
              "WARN_AS_ERROR está configurada en FAIL_ON_WARNINGS_PRINT, Doxygen se\n"
              "comportara como FAIL_ON_WARNINGS pero en caso de que no se defina\n"
              "WARN_LOGFILE, Doxygen no escribirá los mensajes de advertencia entre otros\n"
              "mensajes sino que los escribirá al final de una ejecución. En caso de que se\n"
              "defina WARN_LOGFILE, los mensajes de advertencia además de estar en el archivo\n"
              "definido también se mostrarán al final de una ejecución, a menos que\n"
              "WARN_LOGFILE se defina como -, es decir, salida estándar (stdout), en ese caso\n"
              "el comportamiento seguirá siendo como con la configuración FAIL_ON_WARNINGS.\n"
              "Los valores posibles son:NO, YES, FAIL_ON_WARNINGSyFAIL_ON_WARNINGS_PRINT.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "WARN_FORMAT",
              "La etiqueta WARN_FORMAT determina el formato de los mensajes de advertencia\n"
              "que Doxygen puede producir. La cadena debe contener las etiquetas $file, $line\n"
              "y $text, que serán reemplazadas por el archivo y número de línea desde donde\n"
              "se origino la advertencia y el texto de la advertencia. Opcionalmente, el\n"
              "formato puede contener $versión, que será reemplazado por la versión del\n"
              "archivo (si se pudo obtener a través de FILE_VERSION_FILTER).\n"
              "Ver también: WARN_LINE_FORMAT\n"
              "El valor predeterminado es: $file:$line: $text."
          );
  doc->add(
              "WARN_LINE_FORMAT",
              "En la parte $text del comando WARN_FORMAT, es posible que se proporcione una\n"
              "referencia a un lugar más específico. Para facilitar el salto a este lugar\n"
              "(fuera de Doxygen), el usuario puede definir una cadena personalizada de\n"
              "\"cortar\"/\"pegar\". Ejemplo:\n"
              "WARN_LINE_FORMAT = \"'vi $file +$line'\"\n"
              "Ver también: WARN_FORMAT\n"
              "El valor predeterminado es: at line $line of file $file."
          );
  doc->add(
              "WARN_LOGFILE",
              "La etiqueta WARN_LOGFILE se puede usar para especificar un archivo en el que\n"
              "se deben escribir los mensajes de advertencia y error. Si se deja vacío, la\n"
              "salida se escribe en el error estándar (stderr). En caso de que el archivo\n"
              "especificado no se pueda abrir para escritura, los mensajes de advertencia y\n"
              "error se escriben en el error estándar. Cuando se especifica el archivo -, los\n"
              "mensajes de advertencia y error se escriben en la salida estándar (stdout)."
          );
  doc->add(
              "INPUT",
              "La etiqueta INPUT se usa para especificar los archivos y/o directorios que\n"
              "contienen los archivos de código fuente y otros archivos de documentación.\n"
              "Puede ingresar nombres de archivo como myfile.cpp o directorios como\n"
              "/usr/src/myproject. Separe los archivos o directorios con espacios. Vea\n"
              "también FILE_PATTERNS y EXTENSION_MAPPING.\n"
              "Nota: Si esta etiqueta está vacía, se buscará en el directorio actual."
          );
  doc->add(
              "INPUT_ENCODING",
              "Esta etiqueta se puede usar para especificar la codificación de caracteres de\n"
              "los archivos fuente que Doxygen analiza. Internamente, Doxygen usa la\n"
              "codificación UTF-8. Doxygen usa libiconv (o el iconv incorporado en libc) para\n"
              "la transcodificación. Vea la documentación de libiconv (see:\n"
              "https://www.gnu.org/software/libiconv/) para la lista de codificaciones\n"
              "posibles.\n"
              "Ver también: INPUT_FILE_ENCODING\n"
              "El valor predeterminado es: UTF-8."
          );
  doc->add(
              "INPUT_FILE_ENCODING",
              "Esta etiqueta se puede usar para especificar la codificación de caracteres de\n"
              "los archivos fuente que Doxygen analiza. La etiqueta INPUT_FILE_ENCODING se\n"
              "puede usar para especificar la codificación de caracteres por patrón de\n"
              "archivo. Doxygen comparara el nombre del archivo con cada patrón y aplicará la\n"
              "codificación en lugar de la INPUT_ENCODING predeterminada cuando haya una\n"
              "coincidencia. Las codificaciones de caracteres son una lista de la forma:\n"
              "patrón=codificación (como *.php=ISO-8859-1).\n"
              "Ver también: INPUT_ENCODING para más información sobre codificaciones\n"
              "soportadas."
          );
  doc->add(
              "FILE_PATTERNS",
              "Si el valor de la etiqueta INPUT contiene directorios, puede usar la etiqueta\n"
              "FILE_PATTERNS para especificar uno o más patrones de comodín (como *.cpp y\n"
              "*.h) para filtrar los archivos fuente en los directorios.\n"
              "\n"
              "Tenga en cuenta que para extensiones personalizadas o extensiones no\n"
              "soportadas directamente, también debe configurar EXTENSION_MAPPING para la\n"
              "extensión, de lo contrario los archivos no serán leidos por Doxygen.\n"
              "\n"
              "Tenga en cuenta que la lista de patrones de archivo verificados por defecto\n"
              "puede diferir de la lista de mapeos de extensiones de archivo predeterminados.\n"
              "\n"
              "Si se deja vacío, se verificaran los siguientes patrones:*.c, *.cc, *.cxx,\n"
              "*.cxxm, *.cpp, *.cppm, *.ccm, *.c++, *.c++m, *.java, *.ii, *.ixx, *.ipp,\n"
              "*.i++, *.inl, *.idl, *.ddl, *.odl, *.h, *.hh, *.hxx, *.hpp, *.h++, *.l, *.cs,\n"
              "*.d, *.php, *.php4, *.php5, *.phtml, *.inc, *.m, *.markdown, *.md, *.mm, *.dox\n"
              "(to be provided as Doxygen C comment), *.py, *.pyw, *.f90, *.f95, *.f03,\n"
              "*.f08, *.f18, *.f, *.for, *.vhd, *.vhdl, *.ucf, *.qsfy*.ice."
          );
  doc->add(
              "RECURSIVE",
              "La etiqueta RECURSIVE se puede usar para especificar si también se deben\n"
              "buscar subdirectorios en busca de archivos de entrada.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "EXCLUDE",
              "La etiqueta EXCLUDE se puede usar para especificar archivos y/o directorios\n"
              "que deben excluirse de los archivos fuente INPUT. De esta manera puede excluir\n"
              "fácilmente un subdirectorio de un árbol de directorios cuya raíz se especifica\n"
              "con la etiqueta INPUT.\n"
              "\n"
              "Tenga en cuenta que las rutas relativas son relativas al directorio desde\n"
              "donde se ejecuta Doxygen."
          );
  doc->add(
              "EXCLUDE_SYMLINKS",
              "La etiqueta EXCLUDE_SYMLINKS se puede usar para seleccionar si los archivos o\n"
              "directorios que son enlaces simbólicos deben excluirse de la entrada.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "EXCLUDE_PATTERNS",
              "Si el valor de la etiqueta INPUT contiene directorios, puede usar la etiqueta\n"
              "EXCLUDE_PATTERNS para especificar uno o más patrones de comodín para excluir\n"
              "ciertos archivos de esos directorios.\n"
              "\n"
              "Nota: Los comodines se comparan contra el archivo con ruta absoluta, por lo\n"
              "que para excluir todos los directorios de prueba, por ejemplo, use el patrón\n"
              "*/test/*"
          );
  doc->add(
              "EXCLUDE_SYMBOLS",
              "La etiqueta EXCLUDE_SYMBOLS se puede usar para especificar uno o más nombres\n"
              "de símbolos (espacios de nombres, clases, funciones, etc.) que deben excluirse\n"
              "de la salida. El nombre del símbolo puede ser un nombre completamente\n"
              "calificado, una palabra, o si se usa el comodín *, una subcadena. Ejemplos:\n"
              "ANamespace, AClass, ANamespace::AClass, ANamespace::*Test"
          );
  doc->add(
              "EXAMPLE_PATH",
              "La etiqueta EXAMPLE_PATH se puede usar para especificar uno o más archivos o\n"
              "directorios que contienen fragmentos de código de ejemplo que se incluyen (vea\n"
              "el comando \\include)."
          );
  doc->add(
              "EXAMPLE_PATTERNS",
              "Si el valor de la etiqueta EXAMPLE_PATH contiene directorios, puede usar la\n"
              "etiqueta EXAMPLE_PATTERNS para especificar uno o más patrones de comodín para\n"
              "filtrar los archivos fuente en los directorios. Si se deja vacío, se incluyen\n"
              "todos los archivos."
          );
  doc->add(
              "EXAMPLE_RECURSIVE",
              "Si la etiqueta EXAMPLE_RECURSIVE está configurada en YES, se buscarán\n"
              "subdirectorios en los directorios especificados con EXAMPLE_PATH en busca de\n"
              "archivos de entrada para los comandos \\include o \\dontinclude,\n"
              "independientemente del valor de la etiqueta RECURSIVE.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "IMAGE_PATH",
              "La etiqueta IMAGE_PATH se puede usar para especificar uno o más directorios\n"
              "que contienen imagenes que se incluyen en la documentación (vea el comando\n"
              "\\image)."
          );
  doc->add(
              "INPUT_FILTER",
              "La etiqueta INPUT_FILTER se puede usar para especificar un programa que\n"
              "Doxygen debe invocar para cada archivo de entrada. Doxygen invocará el\n"
              "programa de filtro ejecutando (via popen()) el comando:\n"
              "\n"
              "<filtro> <archivo-entrada>\n"
              "\n"
              "donde <filtro> es el valor de la etiqueta INPUT_FILTER y <archivo-entrada> es\n"
              "el nombre de un archivo de entrada. Doxygen usará entonces la salida que el\n"
              "programa de filtro escriba en la salida estándar. Si FILTER_PATTERNS está\n"
              "especificado, esta etiqueta se ignorará.\n"
              "\n"
              "Tenga en cuenta que el filtro no debe agregar ni eliminar líneas; se aplica\n"
              "antes de que se escanee el código, pero no cuando se genera el código de\n"
              "salida. Si se agregan o eliminan líneas, los anclajes no se colocarán\n"
              "correctamente.\n"
              "\n"
              "Tenga en cuenta que Doxygen usará los datos procesados y escritos en la salida\n"
              "estándar para su posterior procesamiento, por lo que no se debe escribir nada\n"
              "más, como declaraciones de depuración o comandos usados (así que en el caso de\n"
              "un archivo por lotes de Windows, siempre use @echo OFF).\n"
              "\n"
              "Tenga en cuenta que para extensiones personalizadas o extensiones no\n"
              "soportadas directamente, también debe configurar EXTENSION_MAPPING para la\n"
              "extensión, de lo contrario los archivos no serán procesados correctamente por\n"
              "Doxygen.\n"
              ""
          );
  doc->add(
              "FILTER_PATTERNS",
              "La etiqueta FILTER_PATTERNS se puede usar para especificar filtros basados en\n"
              "patrones de archivo. Doxygen comparara el nombre del archivo con cada patrón y\n"
              "aplicará el filtro si hay una coincidencia. Los filtros son una lista de la\n"
              "forma: patrón=filtro (como *.cpp=my_cpp_filter). Vea INPUT_FILTER para más\n"
              "información sobre el uso de filtros. Si la etiqueta FILTER_PATTERNS está vacía\n"
              "o ninguno de los patrones coincide con el nombre del archivo, se aplicará\n"
              "INPUT_FILTER.\n"
              "\n"
              "Tenga en cuenta que para extensiones personalizadas o extensiones no\n"
              "soportadas directamente, también debe configurar EXTENSION_MAPPING para la\n"
              "extensión, de lo contrario los archivos no serán procesados correctamente por\n"
              "Doxygen.\n"
              ""
          );
  doc->add(
              "FILTER_SOURCE_FILES",
              "Si la etiqueta FILTER_SOURCE_FILES está configurada en YES, el filtro de\n"
              "entrada (si se configura con INPUT_FILTER) también se usará para filtrar los\n"
              "archivos de entrada utilizados para crear los archivos fuente para navegar (es\n"
              "decir, cuando SOURCE_BROWSER está configurado en YES).\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "FILTER_SOURCE_PATTERNS",
              "La etiqueta FILTER_SOURCE_PATTERNS se puede usar para especificar filtros de\n"
              "fuente por patrón de archivo. Un patrón anula la configuración de\n"
              "FILTER_PATTERN (si existe) y también es posible deshabilitar el filtrado de\n"
              "fuente para un patrón particular con *.ext= (es decir, sin nombrar un filtro).\n"
              "Esta etiqueta requiere que la etiqueta FILTER_SOURCE_FILES esté establecida en\n"
              "YES."
          );
  doc->add(
              "USE_MDFILE_AS_MAINPAGE",
              "Si la etiqueta USE_MDFILE_AS_MAINPAGE se refiere al nombre de un archivo\n"
              "markdown que es parte de la entrada, su contenido se colocará en la página\n"
              "principal (index.html). Esto puede ser útil si tiene un proyecto en, por\n"
              "ejemplo, GitHub y desea reutilizar el archivo README.md como página principal."
          );
  doc->add(
              "IMPLICIT_DIR_DOCS",
              "Si la etiqueta IMPLICIT_DIR_DOCS está configurada en YES, cualquier archivo\n"
              "README.md encontrado en los subdirectorios de la raíz del proyecto se usará\n"
              "como documentación para ese subdirectorio, a menos que el README.md comience\n"
              "con un comando \\dir, \\page o \\mainpage. Si se configura en NO, el archivo\n"
              "README.md debe comenzar con un comando \\dir explícito para ser usado como\n"
              "documentación del directorio.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "FORTRAN_COMMENT_AFTER",
              "El estándar Fortran especifica que para el código Fortran de formato fijo,\n"
              "todos los caracteres desde la posición 72 se consideran comentarios. Una\n"
              "extensión común es permitir líneas más largas antes de que comience el\n"
              "comentario automático. La configuración FORTRAN_COMMENT_AFTER también hace\n"
              "posible que se procesen líneas más largas antes de que comience el comentario\n"
              "automático.\n"
              "Valor mínimo: 7, valor máximo: 10000, valor predeterminado: 72."
          );
  doc->add(
              "SOURCE_BROWSER",
              "Si la etiqueta SOURCE_BROWSER está configurada en YES, se generará una lista\n"
              "de archivos fuente. Las entidades documentadas serán referenciadas cruzadas\n"
              "con estas fuentes.\n"
              "\n"
              "Nota: Para deshacerse de todo el código fuente en la salida generada,\n"
              "asegurese de que también VERBATIM_HEADERS este configurado en NO.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "INLINE_SOURCES",
              "Si la etiqueta INLINE_SOURCES está configurada en YES, el cuerpo de funciones,\n"
              "macros multilínea, enumeraciones o variables inicializadas con lista se\n"
              "insertará directamente en la documentación.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "STRIP_CODE_COMMENTS",
              "Configurar la etiqueta STRIP_CODE_COMMENTS en YES indicará a Doxygen que\n"
              "oculte cualquier bloque de comentario especial de los fragmentos de código\n"
              "fuente generados. Los comentarios normales de C, C++ y Fortran siempre\n"
              "permaneceran visibles.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "REFERENCED_BY_RELATION",
              "Si la etiqueta REFERENCED_BY_RELATION está configurada en YES, para cada\n"
              "entidad documentada se listarán todas las funciones documentadas que la\n"
              "referencian.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "REFERENCES_RELATION",
              "Si la etiqueta REFERENCES_RELATION está configurada en YES, para cada función\n"
              "documentada se listarán todas las entidades documentadas llamadas/usadas por\n"
              "esa función.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "REFERENCES_LINK_SOURCE",
              "Si la etiqueta REFERENCES_LINK_SOURCE está configurada en YES y la etiqueta\n"
              "SOURCE_BROWSER está configurada en YES, entonces los hipervinculos de las\n"
              "funciones en las listas REFERENCES_RELATION y REFERENCED_BY_RELATION enlazaran\n"
              "al código fuente. De lo contrario, enlazaran a la documentación.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "SOURCE_TOOLTIPS",
              "Si SOURCE_TOOLTIPS está habilitado (el valor predeterminado), al pasar el\n"
              "cursor sobre un hipervinculo en el código fuente se mostrará una descripción\n"
              "emergente con información adicional como prototipo, descripción breve y\n"
              "enlaces a la definición y documentación. Dado que esto hará que el archivo\n"
              "HTML sea más grande y la carga de archivos grandes sea un poco más lenta,\n"
              "puede optar por deshabilitar esta función.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta SOURCE_BROWSER esté establecida en YES."
          );
  doc->add(
              "USE_HTAGS",
              "Si la etiqueta USE_HTAGS está configurada en YES, las referencias al código\n"
              "fuente apuntaran al HTML generado por la herramienta htags(1) en lugar del\n"
              "navegador de código fuente incorporado de Doxygen. La herramienta htags es\n"
              "parte del sistema de etiquetado de código fuente global de GNU (vea\n"
              "https://www.gnu.org/software/global/global.html). Necesitara la versión 4.8.6\n"
              "o superior.\n"
              "\n"
              "Para usarlo haga lo siguiente:\n"
              "- Instale la última versión de global\n"
              "- Habilite SOURCE_BROWSER y USE_HTAGS en el archivo de configuración\n"
              "- Asegurese de que INPUT apunte a la raíz del árbol de fuentes\n"
              "- Ejecute doxygen como de costumbre\n"
              "\n"
              "Doxygen invocará htags (y eso a su vez invocará gtags), por lo que estas\n"
              "herramientas deben estar disponibles desde la línea de comandos (es decir, en\n"
              "la ruta de búsqueda).\n"
              "\n"
              "El resultado: en lugar del navegador de código fuente generado por Doxygen,\n"
              "los enlaces al código fuente ahora apuntaran a la salida de htags.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta SOURCE_BROWSER esté establecida en YES."
          );
  doc->add(
              "VERBATIM_HEADERS",
              "Si la etiqueta VERBATIM_HEADERS está configurada en YES, Doxygen generará una\n"
              "copia literal del archivo de encabezado para cada clase para la cual se\n"
              "especifica una inclusión. Configure en NO para deshabilitar esto.\n"
              "Ver también: Sección \\class.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "CLANG_ASSISTED_PARSING",
              "Si la etiqueta CLANG_ASSISTED_PARSING está configurada en YES, Doxygen usará\n"
              "el analizador clang para un análisis más preciso a costa de un rendimiento\n"
              "reducido. Esto puede ser particularmente útil para código C++ rico en\n"
              "plantillas para el cual el analizador integrado de Doxygen carece de la\n"
              "información de tipo necesaria.\n"
              "Nota: La disponibilidad de esta opción depende de si Doxygen fue generado con\n"
              "la opción -Duse_libclang=ON para CMake.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "CLANG_ADD_INC_PATHS",
              "Si la etiqueta CLANG_ASSISTED_PARSING está configurada en YES y la etiqueta\n"
              "CLANG_ADD_INC_PATHS está configurada en YES, Doxygen agregará el directorio de\n"
              "cada entrada a la ruta de inclusión.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta CLANG_ASSISTED_PARSING esté establecida\n"
              "en YES."
          );
  doc->add(
              "CLANG_OPTIONS",
              "Si el análisis asistido por clang está habilitado, puede proporcionar al\n"
              "compilador opciones de línea de comandos que normalmente usaria al invocar el\n"
              "compilador. Tenga en cuenta que las rutas de inclusión ya están configuradas\n"
              "por Doxygen para los archivos y directorios especificados con INPUT y\n"
              "INCLUDE_PATH.\n"
              "Esta etiqueta requiere que la etiqueta CLANG_ASSISTED_PARSING esté establecida\n"
              "en YES."
          );
  doc->add(
              "CLANG_DATABASE_PATH",
              "Si el análisis asistido por clang está habilitado, puede proporcionar al\n"
              "analizador clang la ruta al directorio que contiene un archivo llamado\n"
              "compile_commands.json. Este archivo puede ser generado por CMake con la opción\n"
              "CMAKE_EXPORT_COMPILE_COMMANDS. Esto es equivalente a especificar la opción -p\n"
              "a una herramienta clang, como clang-check. Estas opciones se pasarán al\n"
              "analizador. También se agregarán las opciones especificadas con CLANG_OPTIONS.\n"
              "Nota: La disponibilidad de esta opción depende de si Doxygen fue generado con\n"
              "la opción -Duse_libclang=ON para CMake."
          );
  doc->add(
              "ALPHABETICAL_INDEX",
              "Si la etiqueta ALPHABETICAL_INDEX está configurada en YES, se generará un\n"
              "índice alfabético de todos los compuestos. Habilítela si el proyecto contiene\n"
              "muchas clases, estructuras, uniones o interfaces.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "IGNORE_PREFIX",
              "La etiqueta IGNORE_PREFIX se puede usar para especificar uno o más prefijos\n"
              "que deben ignorarse al generar los encabezados de índice. La etiqueta\n"
              "IGNORE_PREFIX funciona para nombres de clases, funciones y miembros. La\n"
              "entidad se colocará en la lista alfabética bajo la primera letra del nombre de\n"
              "la entidad que queda después de eliminar el prefijo.\n"
              "Esta etiqueta requiere que la etiqueta ALPHABETICAL_INDEX esté establecida en\n"
              "YES."
          );
  doc->add(
              "GENERATE_HTML",
              "Si la etiqueta GENERATE_HTML está configurada en YES, Doxygen generará salida\n"
              "HTML.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "HTML_OUTPUT",
              "La etiqueta HTML_OUTPUT se usa para especificar donde se colocarán los\n"
              "documentos HTML. Si se ingresa una ruta relativa, el valor de OUTPUT_DIRECTORY\n"
              "se antepondrá.\n"
              "El directorio predeterminado es: html.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_FILE_EXTENSION",
              "La etiqueta HTML_FILE_EXTENSION se puede usar para especificar la extensión de\n"
              "archivo para cada página HTML generada (por ejemplo: .htm, .php, .asp).\n"
              "El valor predeterminado es: .html.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_HEADER",
              "La etiqueta HTML_HEADER se puede usar para especificar un archivo de\n"
              "encabezado HTML personalizado para cada página HTML generada. Si la etiqueta\n"
              "se deja vacía, Doxygen generará un encabezado estándar.\n"
              "\n"
              "Para obtener HTML válido, el archivo de encabezado debe contener todos los\n"
              "scripts y hojas de estilo que Doxygen necesita, lo cual depende de las\n"
              "opciones de configuración usadas (por ejemplo, la configuración\n"
              "GENERATE_TREEVIEW). Se recomienda encarecidamente comenzar con un encabezado\n"
              "estándar usando\n"
              "doxygen -w html new_header.html new_footer.html new_stylesheet.css\n"
              "YourConfigFile\n"
              "y luego modificar el archivo new_header.html. Vea también la sección \"Doxygen\n"
              "usage\" para información sobre como generar el encabezado estándar que Doxygen\n"
              "normalmente usa.\n"
              "Nota: El encabezado puede cambiar, por lo que generalmente necesita regenerar\n"
              "el encabezado estándar cuando actualiza a una versión más nueva de\n"
              "Doxygen.Para una descripción de los posibles marcadores y nombres de bloques,\n"
              "vea la documentación.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_FOOTER",
              "La etiqueta HTML_FOOTER se puede usar para especificar un pie de página HTML\n"
              "personalizado para cada página HTML generada. Si la etiqueta se deja vacía,\n"
              "Doxygen generará un pie de página estándar. Vea HTML_HEADER para más\n"
              "información sobre como generar un pie de página estándar y que comandos\n"
              "especiales se pueden usar dentro del pie de página. Vea también la sección\n"
              "\"Doxygen usage\" para información sobre como generar el pie de página estándar\n"
              "que Doxygen normalmente usa.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_STYLESHEET",
              "La etiqueta HTML_STYLESHEET se puede usar para especificar una hoja de estilo\n"
              "en cascada personalizada que es usada por cada página HTML. Se puede usar para\n"
              "ajustar la apariencia de la salida HTML. Si se deja vacío, Doxygen generará\n"
              "una hoja de estilo estándar. Vea también la sección \"Doxygen usage\" para\n"
              "información sobre como generar la hoja de estilo que Doxygen normalmente usa.\n"
              "Nota: Se recomienda usar HTML_EXTRA_STYLESHEET en lugar de esta etiqueta, ya\n"
              "que es más robusto y esta etiqueta (HTML_STYLESHEET) quedara obsoleta en el\n"
              "futuro.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_EXTRA_STYLESHEET",
              "La etiqueta HTML_EXTRA_STYLESHEET se puede usar para especificar hojas de\n"
              "estilo en cascada personalizadas adicionales que se incluirán después de las\n"
              "hojas de estilo estándar creadas por Doxygen. Con esta opción puede anular\n"
              "ciertos aspectos de estilo. Esto es preferible al uso de HTML_STYLESHEET ya\n"
              "que no reemplaza la hoja de estilo estándar y por lo tanto es más robusto\n"
              "frente a actualizaciones futuras. Doxygen copiará los archivos de hoja de\n"
              "estilo en el directorio de salida.\n"
              "Nota: El orden de los archivos de hoja de estilo adicionales es importante\n"
              "(por ejemplo, la última hoja de estilo en la lista anula la configuración de\n"
              "las anteriores en la lista).\n"
              "Nota: Dado que el estilo de las barras de desplazamiento en webkit/Chromium\n"
              "actualmente no se puede anular, el estilo del archivo estándar doxygen.css se\n"
              "omite cuando se especifican una o más hojas de estilo adicionales. Entonces,\n"
              "si se desea personalizar las barras de desplazamiento, debe agregarse\n"
              "explícitamente.Para un ejemplo, vea la documentación.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_EXTRA_FILES",
              "La etiqueta HTML_EXTRA_FILES se puede usar para especificar una o más imagenes\n"
              "adicionales u otros archivos de origen que deben copiarse en el directorio de\n"
              "salida HTML. Tenga en cuenta que estos archivos se copiarán en el directorio\n"
              "de salida HTML base. Use el marcador $relpath^ en los archivos HTML_HEADER y/o\n"
              "HTML_FOOTER para cargar estos archivos. En el archivo HTML_STYLESHEET use solo\n"
              "el nombre del archivo. Tenga en cuenta también que los archivos se copian tal\n"
              "como están; no hay comandos o marcadores disponibles.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_COLORSTYLE",
              "La etiqueta HTML_COLORSTYLE se puede usar para especificar si la salida HTML\n"
              "generada se renderiza con un tema oscuro o claro.\n"
              "Los valores posibles son:LIGHT siempre genera salida en modo claro, DARK\n"
              "siempre genera salida en modo oscuro, AUTO_LIGHT establece automáticamente el\n"
              "modo según la preferencia del usuario, usa modo claro si no hay preferencia\n"
              "establecida (predeterminado), AUTO_DARK establece automáticamente el modo\n"
              "según la preferencia del usuario, usa modo oscuro si no hay preferencia\n"
              "establecidayTOGGLE permite al usuario cambiar entre modo claro y oscuro\n"
              "mediante un botón.\n"
              "El valor predeterminado es: AUTO_LIGHT.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_COLORSTYLE_HUE",
              "La etiqueta HTML_COLORSTYLE_HUE controla el color de la salida HTML. Doxygen\n"
              "ajustará los colores en la hoja de estilo y las imagenes de fondo de acuerdo\n"
              "con este color. El tono se especifica como un ángulo en una rueda de color,\n"
              "vea https://en.wikipedia.org/wiki/Hue para más información. Por ejemplo, el\n"
              "valor 0 representa rojo, 60 es amarillo, 120 es verde, 180 es cian, 240 es\n"
              "azul, 300 es púrpura y 360 es rojo de nuevo.\n"
              "Valor mínimo: 0, valor máximo: 359, valor predeterminado: 220.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_COLORSTYLE_SAT",
              "La etiqueta HTML_COLORSTYLE_SAT controla la pureza (o saturación) de los\n"
              "colores en la salida HTML. Para un valor de 0, la salida usa solo escalas de\n"
              "grises. Un valor de 255 producirá los colores más vivos.\n"
              "Valor mínimo: 0, valor máximo: 255, valor predeterminado: 100.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_COLORSTYLE_GAMMA",
              "La etiqueta HTML_COLORSTYLE_GAMMA controla la corrección gamma aplicada al\n"
              "componente de luminancia de los colores en la salida HTML. Valores por debajo\n"
              "de 100 hacen que la salida sea gradualmente más clara, mientras que valores\n"
              "por encima de 100 hacen que la salida sea más oscura. El valor dividido por\n"
              "100 es la gamma realmente aplicada, por lo que 80 representa una gamma de 0.8,\n"
              "el valor 220 representa una gamma de 2.2, y 100 no cambia la gamma.\n"
              "Valor mínimo: 40, valor máximo: 240, valor predeterminado: 80.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_DYNAMIC_MENUS",
              "Si la etiqueta HTML_DYNAMIC_MENUS está configurada en YES, la documentación\n"
              "HTML generada incluirá un índice principal con menús de navegación verticales\n"
              "creados dinámicamente a través de JavaScript. Si está deshabilitado, el índice\n"
              "de navegación consiste en múltiples niveles de pestañas que se incrustan\n"
              "estáticamente en cada página HTML. Deshabilite esta opción para soportar\n"
              "navegadores que no tienen JavaScript, como el navegador de ayuda Qt.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_DYNAMIC_SECTIONS",
              "Si la etiqueta HTML_DYNAMIC_SECTIONS está configurada en YES, la documentación\n"
              "HTML generada contendrá secciones que se pueden mostrar y ocultar después de\n"
              "que se cargue la página.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_CODE_FOLDING",
              "Si la etiqueta HTML_CODE_FOLDING está configurada en YES, las clases y\n"
              "funciones en el código fuente HTML generado se pueden colapsar y expandir\n"
              "dinámicamente.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_COPY_CLIPBOARD",
              "Si la etiqueta HTML_COPY_CLIPBOARD está configurada en YES, Doxygen mostrará\n"
              "un icono en la esquina superior derecha de los fragmentos de código y texto\n"
              "que permite al usuario copiar el contenido al portapapeles. Tenga en cuenta\n"
              "que esto solo funciona si el navegador lo soporta y la página web se sirve a\n"
              "través de un contexto seguro (see:\n"
              "https://www.w3.org/TR/secure-contexts/), es decir, usando el protocolo https:\n"
              "o file:.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_PROJECT_COOKIE",
              "Doxygen almacena algunas configuraciones permanentemente en el navegador (por\n"
              "ejemplo, a través de cookies). Por defecto, estas configuraciones se aplican a\n"
              "todas las páginas HTML generadas por Doxygen en todos los proyectos. La\n"
              "etiqueta HTML_PROJECT_COOKIE se puede usar para almacenar las configuraciones\n"
              "bajo una clave específica del proyecto, de modo que la configuración del\n"
              "usuario se guarde por separado.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_INDEX_NUM_ENTRIES",
              "Con HTML_INDEX_NUM_ENTRIES se puede controlar el número preferido de entradas\n"
              "que se muestran inicialmente en los varios índices en forma de árbol; el\n"
              "usuario puede expandir y colapsar entradas dinámicamente más tarde. Doxygen\n"
              "expandirá el árbol a un nivel tal que a lo sumo el número especificado de\n"
              "entradas sea visible (a menos que un árbol completamente colapsado ya exceda\n"
              "esta cantidad). Configurar el número de entradas en 1 produce un árbol\n"
              "completamente colapsado por defecto. 0 es un valor especial que representa un\n"
              "número infinito de entradas y resultará en un árbol completamente expandido\n"
              "por defecto.\n"
              "Valor mínimo: 0, valor máximo: 9999, valor predeterminado: 100.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "GENERATE_DOCSET",
              "Si la etiqueta GENERATE_DOCSET está configurada en YES, se generarán archivos\n"
              "de índice adicionales que se pueden usar como entrada para el entorno de\n"
              "desarrollo integrado Xcode 3 de Apple (see:\n"
              "https://developer.apple.com/xcode/) que se introdujo con OSX 10.5 (Leopard).\n"
              "Para crear un conjunto de documentos, Doxygen generará un Makefile en el\n"
              "directorio de salida HTML. Ejecutar make creará el conjunto de documentos en\n"
              "ese directorio y ejecutar make install instalará el conjunto de documentos en\n"
              "~/Library/Developer/Shared/Documentation/DocSets para que Xcode lo encuentre\n"
              "al inicio. Vea https://developer.apple.com/library/archive/featuredarticles/Do\n"
              "xygenXcode/_index.html para más información.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "DOCSET_FEEDNAME",
              "Esta etiqueta determina el nombre del feed del conjunto de documentos. Un feed\n"
              "de documentación proporciona un paraguas bajo el cual se pueden agrupar\n"
              "múltiples conjuntos de documentos de un solo proveedor (por ejemplo, una\n"
              "empresa o una suite de productos).\n"
              "El valor predeterminado es: Doxygen generated docs.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_DOCSET esté establecida en\n"
              "YES."
          );
  doc->add(
              "DOCSET_FEEDURL",
              "Esta etiqueta determina la URL del feed del conjunto de documentos. Un feed de\n"
              "documentación proporciona un paraguas bajo el cual se pueden agrupar múltiples\n"
              "conjuntos de documentos de un solo proveedor (por ejemplo, una empresa o una\n"
              "suite de productos).\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_DOCSET esté establecida en\n"
              "YES."
          );
  doc->add(
              "DOCSET_BUNDLE_ID",
              "Esta etiqueta especifica una cadena que debe identificar de manera única el\n"
              "paquete del conjunto de documentos. Esta debe ser una cadena en estilo de\n"
              "nombre de dominio inverso, por ejemplo, com.mycompany.MyDocSet. Doxygen\n"
              "añadirá .docset al nombre.\n"
              "El valor predeterminado es: org.doxygen.Project.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_DOCSET esté establecida en\n"
              "YES."
          );
  doc->add(
              "DOCSET_PUBLISHER_ID",
              "La etiqueta DOCSET_PUBLISHER_ID especifica una cadena que debe identificar de\n"
              "manera única al editor de documentación. Esta debe ser una cadena en estilo de\n"
              "nombre de dominio inverso, por ejemplo, com.mycompany.MyDocSet.documentation.\n"
              "El valor predeterminado es: org.doxygen.Publisher.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_DOCSET esté establecida en\n"
              "YES."
          );
  doc->add(
              "DOCSET_PUBLISHER_NAME",
              "La etiqueta DOCSET_PUBLISHER_NAME identifica al editor de documentación.\n"
              "El valor predeterminado es: Publisher.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_DOCSET esté establecida en\n"
              "YES."
          );
  doc->add(
              "GENERATE_HTMLHELP",
              "Si la etiqueta GENERATE_HTMLHELP está configurada en YES, Doxygen generará\n"
              "tres archivos de índice HTML adicionales: index.hhp, index.hhc y index.hhk. El\n"
              "index.hhp es un archivo de proyecto que puede ser leido por el Taller de Ayuda\n"
              "HTML de Microsoft en Windows. A principios de 2021, Microsoft desconecto la\n"
              "página original con los enlaces de descarga (el Taller de Ayuda HTML ya estaba\n"
              "en modo de mantenimiento durante muchos anos). Puede descargar el Taller de\n"
              "Ayuda HTML desde los archivos web en ejecutable de instalación (see:\n"
              "http://web.archive.org/web/20160201063255/https://download.microsoft.com/downl\n"
              "oad/0/A/9/0A939EF6-E31C-430F-A3DF-DFAE7960D564/htmlhelp.exe).\n"
              "\n"
              "El Taller de Ayuda HTML contiene un compilador que convertirá toda la salida\n"
              "HTML generada por Doxygen en un único archivo HTML compilado (.chm). Los\n"
              "archivos HTML compilados ahora se usan como el formato de ayuda de Windows 98\n"
              "y reemplazarán el antiguo formato de ayuda de Windows (.hlp) en todas las\n"
              "plataformas Windows en el futuro. Los archivos HTML comprimidos también\n"
              "contienen un índice, una tabla de contenidos y puede buscar palabras en la\n"
              "documentación. El taller HTML también contiene un visor para archivos HTML\n"
              "comprimidos.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "CHM_FILE",
              "La etiqueta CHM_FILE se puede usar para especificar el nombre del archivo .chm\n"
              "resultante. Una ruta relativa se interpreta relativa al directorio\n"
              "HTML_OUTPUT. Si se deja vacío, se usa el valor predeterminado index.chm.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTMLHELP esté establecida en\n"
              "YES."
          );
  doc->add(
              "HHC_LOCATION",
              "La etiqueta HHC_LOCATION se puede usar para especificar la ubicación (ruta\n"
              "absoluta incluyendo nombre de archivo) del compilador de ayuda HTML (hhc.exe).\n"
              "Si no está vacío, Doxygen intentará ejecutar el compilador de ayuda HTML en el\n"
              "archivo index.hhp generado.\n"
              "El archivo debe especificarse con la ruta completa.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTMLHELP esté establecida en\n"
              "YES."
          );
  doc->add(
              "GENERATE_CHI",
              "La bandera GENERATE_CHI controla si se genera un archivo de índice .chi\n"
              "separado (YES) o si debe incluirse en el archivo principal .chm (NO).\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTMLHELP esté establecida en\n"
              "YES."
          );
  doc->add(
              "CHM_INDEX_ENCODING",
              "La etiqueta CHM_INDEX_ENCODING se usa para codificar el contenido del índice,\n"
              "contenido y archivo de proyecto de HtmlHelp. Por defecto se usa la\n"
              "codificación de la salida HTML.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTMLHELP esté establecida en\n"
              "YES."
          );
  doc->add(
              "BINARY_TOC",
              "La bandera BINARY_TOC controla si se genera un tabla de contenidos binaria. Si\n"
              "se configura en YES, se creará una tabla de contenidos binaria, lo que\n"
              "resultará en una búsqueda más rápida y archivos más pequeños. La tabla de\n"
              "contenidos predeterminada se almacena en un archivo de texto.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTMLHELP esté establecida en\n"
              "YES."
          );
  doc->add(
              "TOC_EXPAND",
              "La bandera TOC_EXPAND se puede configurar en YES para agregar elementos\n"
              "adicionales para miembros de grupos a la tabla de contenidos de la\n"
              "documentación de ayuda HTML y a la vista de árbol.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTMLHELP esté establecida en\n"
              "YES."
          );
  doc->add(
              "SITEMAP_URL",
              "La etiqueta SITEMAP_URL se usa para especificar la URL completa del lugar\n"
              "donde el usuario colocará la documentación generada en el servidor durante el\n"
              "despliegue de la documentación. El mapa del sitio generado se llama\n"
              "sitemap.xml y se coloca en el directorio especificado por HTML_OUTPUT. En caso\n"
              "de que no se especifique SITEMAP_URL, no se genera mapa del sitio. Para\n"
              "información sobre el protocolo del mapa del sitio vea https://www.sitemaps.org\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "GENERATE_QHP",
              "Si la etiqueta GENERATE_QHP está configurada en YES y tanto QHP_NAMESPACE como\n"
              "QHP_VIRTUAL_FOLDER están configurados, se generará un archivo de índice\n"
              "adicional que se puede usar como entrada para el qhelpgenerator de Qt para\n"
              "crear una Ayuda Comprimida de Qt (.qch) de la documentación HTML generada.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "QCH_FILE",
              "Si la etiqueta QHG_LOCATION está especificada, la etiqueta QCH_FILE se puede\n"
              "usar para especificar el nombre del archivo .qch resultante. La ruta\n"
              "especificada es relativa a la carpeta de salida HTML.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_QHP esté establecida en YES."
          );
  doc->add(
              "QHP_NAMESPACE",
              "La etiqueta QHP_NAMESPACE especifica el espacio de nombres a usar al generar\n"
              "la salida del Proyecto de Ayuda Qt. Para más información, vea Qt Help Project\n"
              "/ Namespace (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#namespace).\n"
              "El valor predeterminado es: org.doxygen.Project.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_QHP esté establecida en YES."
          );
  doc->add(
              "QHP_VIRTUAL_FOLDER",
              "La etiqueta QHP_VIRTUAL_FOLDER especifica el espacio de nombres a usar al\n"
              "generar la salida del Proyecto de Ayuda Qt. Para más información, vea Qt Help\n"
              "Project / Virtual Folders (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#virtual-folders).\n"
              "El valor predeterminado es: doc.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_QHP esté establecida en YES."
          );
  doc->add(
              "QHP_CUST_FILTER_NAME",
              "Si la etiqueta QHP_CUST_FILTER_NAME está configurada, especifica el nombre de\n"
              "un filtro personalizado a agregar. Para más información, vea Qt Help Project /\n"
              "Custom Filters (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters).\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_QHP esté establecida en YES."
          );
  doc->add(
              "QHP_CUST_FILTER_ATTRS",
              "La etiqueta QHP_CUST_FILTER_ATTRS especifica la lista de atributos del filtro\n"
              "personalizado a agregar. Para más información, vea Qt Help Project / Custom\n"
              "Filters (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters).\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_QHP esté establecida en YES."
          );
  doc->add(
              "QHP_SECT_FILTER_ATTRS",
              "La etiqueta QHP_SECT_FILTER_ATTRS especifica la lista de atributos con los que\n"
              "coincide la sección de filtro de este proyecto. Qt Help Project / Filter\n"
              "Attributes (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#filter-attributes).\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_QHP esté establecida en YES."
          );
  doc->add(
              "QHG_LOCATION",
              "La etiqueta QHG_LOCATION se puede usar para especificar la ubicación (ruta\n"
              "absoluta incluyendo nombre de archivo) del qhelpgenerator de Qt. Si no está\n"
              "vacío, Doxygen intentará ejecutar qhelpgenerator en el archivo .qhp generado.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_QHP esté establecida en YES."
          );
  doc->add(
              "GENERATE_ECLIPSEHELP",
              "Si la etiqueta GENERATE_ECLIPSEHELP está configurada en YES, se generarán\n"
              "archivos de índice adicionales que junto con los archivos HTML forman un\n"
              "plugin de ayuda de Eclipse. Para instalar el plugin, coloque el directorio que\n"
              "contiene los archivos HTML y de índice en su directorio de instalación de\n"
              "Eclipse en plugins.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "ECLIPSE_DOC_ID",
              "Un identificador único para el plugin de ayuda de Eclipse. Esta debe ser una\n"
              "cadena en estilo de nombre de dominio inverso, por ejemplo,\n"
              "org.doxygen.Project.\n"
              "El valor predeterminado es: org.doxygen.Project.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_ECLIPSEHELP esté establecida\n"
              "en YES."
          );
  doc->add(
              "DISABLE_INDEX",
              "Si desea tener control total sobre el diseño de las páginas HTML generadas,\n"
              "puede ser necesario deshabilitar el índice y reemplazarlo por el suyo propio.\n"
              "La etiqueta DISABLE_INDEX se puede usar para activar o desactivar el índice\n"
              "condensado (pestañas) en la parte superior de cada página HTML. Un valor de NO\n"
              "habilita el índice y el valor YES lo deshabilita. Dado que las pestañas en el\n"
              "índice contienen la misma información que el árbol de navegación, puede\n"
              "configurar esta opción en YES si también configura GENERATE_TREEVIEW en YES.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "GENERATE_TREEVIEW",
              "La etiqueta GENERATE_TREEVIEW se usa para especificar si se debe generar una\n"
              "estructura de índice en forma de árbol para mostrar información jerárquica. Si\n"
              "el valor de la etiqueta está configurado en YES, se generará un panel lateral\n"
              "que contiene una estructura de índice en forma de árbol (igual que la que se\n"
              "genera para la Ayuda HTML). Para que esto funcione se requiere un navegador\n"
              "que soporte JavaScript, DHTML, CSS y marcos (es decir, cualquier navegador\n"
              "moderno). Los usuarios de Windows probablemente estén mejor usando la función\n"
              "de ayuda HTML. A través de hojas de estilo personalizadas (vea\n"
              "HTML_EXTRA_STYLESHEET) se puede ajustar aún más la apariencia del índice (vea\n"
              "\"Fine-tuning the output\"). Como ejemplo, la hoja de estilo predeterminada\n"
              "generada por Doxygen tiene un ejemplo que muestra como colocar una imagen en\n"
              "la raíz del árbol en lugar del PROJECT_NAME.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "PAGE_OUTLINE_PANEL",
              "Si GENERATE_TREEVIEW está configurado en YES, la opción PAGE_OUTLINE_PANEL\n"
              "determina si se muestra un panel de navegación adicional en el lado derecho de\n"
              "la pantalla, mostrando un esquema del contenido de la página principal,\n"
              "similar a, por ejemplo, https://developer.android.com/reference. Si\n"
              "GENERATE_TREEVIEW está configurado en NO, esta opción no tiene efecto.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "FULL_SIDEBAR",
              "Si GENERATE_TREEVIEW está configurado en YES, la opción FULL_SIDEBAR determina\n"
              "si la barra lateral está limitada al area del árbol de navegación (valor NO) o\n"
              "si debe extenderse a toda la altura de la ventana (valor YES). Configurar esto\n"
              "en YES dará como resultado un diseño similar a, por ejemplo,\n"
              "https://docs.readthedocs.io con más espacio para contenido pero menos espacio\n"
              "para el logotipo del proyecto, título y descripción. Si GENERATE_TREEVIEW está\n"
              "configurado en NO, esta opción no tiene efecto.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "ENUM_VALUES_PER_LINE",
              "La etiqueta ENUM_VALUES_PER_LINE se puede usar para establecer el número de\n"
              "valores de enumeración que Doxygen agrupará en una línea.\n"
              "\n"
              "Tenga en cuenta que un valor de 0 suprimirá completamente los valores de\n"
              "enumeración de la sección de descripción general.\n"
              "Valor mínimo: 0, valor máximo: 20, valor predeterminado: 4.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "SHOW_ENUM_VALUES",
              "Cuando la etiqueta SHOW_ENUM_VALUES está configurada, Doxygen mostrará los\n"
              "valores de enumeración especificados junto a los mnemonicos de enumeración.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "TREEVIEW_WIDTH",
              "Si la vista de árbol está habilitada (vea GENERATE_TREEVIEW), entonces esta\n"
              "etiqueta se puede usar para establecer el ancho inicial (en píxeles) del marco\n"
              "en el que se muestra el árbol.\n"
              "Valor mínimo: 0, valor máximo: 1500, valor predeterminado: 250.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "EXT_LINKS_IN_WINDOW",
              "Si la opción EXT_LINKS_IN_WINDOW está configurada en YES, Doxygen abrirá\n"
              "enlaces a símbolos externos importados a través de archivos de etiquetas en\n"
              "una ventana separada.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "OBFUSCATE_EMAILS",
              "Si la etiqueta OBFUSCATE_EMAILS está configurada en YES, las direcciones de\n"
              "correo electrónico en la salida HTML generada serán ofuscadas para evitar bots\n"
              "de spam.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "HTML_FORMULA_FORMAT",
              "Si la opción HTML_FORMULA_FORMAT está configurada en svg, Doxygen usará la\n"
              "herramienta pdf2svg (vea https://github.com/dawbarton/pdf2svg) o Inkscape (vea\n"
              "https://inkscape.org) para generar formulas como imagenes SVG en lugar de PNGs\n"
              "para la salida HTML. Estas imagenes generalmente se ven mejor en resoluciones\n"
              "escaladas.\n"
              "Los valores posibles son:png (predeterminado)ysvg (se ve mejor pero requiere\n"
              "la herramienta pdf2svg o inkscape).\n"
              "El valor predeterminado es: png.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "FORMULA_FONTSIZE",
              "Use esta etiqueta para cambiar el tamaño de fuente de las formulas LaTeX que\n"
              "se incluyen como imagenes en la documentación HTML. Si cambia el tamaño de\n"
              "fuente después de una ejecución exitosa de Doxygen, debe eliminar manualmente\n"
              "todas las imagenes form_*.png del directorio de salida HTML para forzar su\n"
              "regeneración.\n"
              "Valor mínimo: 8, valor máximo: 50, valor predeterminado: 10.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "FORMULA_MACROFILE",
              "El archivo FORMULA_MACROFILE puede contener comandos LaTeX \\newcommand y\n"
              "\\renewcommand para crear nuevos comandos LaTeX que sirvan como bloques de\n"
              "construcción en las formulas. Vea la sección \"Including formulas\" para más\n"
              "detalles."
          );
  doc->add(
              "USE_MATHJAX",
              "Habilite la opción USE_MATHJAX para renderizar formulas LaTeX usando MathJax\n"
              "(vea https://www.mathjax.org) que usa JavaScript del lado del cliente para el\n"
              "renderizado en lugar de usar bitmaps pre-renderizados. Use esto si no tiene\n"
              "LaTeX instalado o si desea que las formulas se vean más bonitas en la salida\n"
              "HTML. Cuando está habilitado, también puede necesitar instalar MathJax por\n"
              "separado y configurar la ruta usando la opción MATHJAX_RELPATH.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "MATHJAX_VERSION",
              "Con MATHJAX_VERSION es posible especificar la versión de MathJax que se usará.\n"
              "Tenga en cuenta que las diferentes versiones de MathJax tienen diferentes\n"
              "requisitos para las diferentes configuraciones, por lo que es posible que\n"
              "también sea necesario cambiar otras configuraciones de MathJax al cambiar\n"
              "entre las diferentes versiones de MathJax.\n"
              "Los valores posibles son:MathJax_2, MathJax_3yMathJax_4.\n"
              "El valor predeterminado es: MathJax_2.\n"
              "Esta etiqueta requiere que la etiqueta USE_MATHJAX esté establecida en YES."
          );
  doc->add(
              "MATHJAX_FORMAT",
              "Si MathJax está habilitado, puede establecer el formato de salida\n"
              "predeterminado que se usará para la salida de MathJax. Para más detalles sobre\n"
              "el formato de salida, vea MathJax versión 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/output.html), MathJax versión 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/output/index.html) y MathJax versión 4 (see:\n"
              "https://docs.mathjax.org/en/v4.0/output/index.htm).\n"
              "Los valores posibles son:HTML-CSS (más lento, pero con mejor compatibilidad.\n"
              "Este es el nombre para MathJax versión 2, para MathJax versión 3 se traducirá\n"
              "a chtml), NativeMML (es decir, MathML. Solo compatible con MathJax 2. Para\n"
              "MathJax versión 3 se usará chtml en su lugar.), chtml (Este es el nombre para\n"
              "MathJax versión 3, para MathJax versión 2 se traducirá a HTML-CSS)ySVG.\n"
              "El valor predeterminado es: HTML-CSS.\n"
              "Esta etiqueta requiere que la etiqueta USE_MATHJAX esté establecida en YES."
          );
  doc->add(
              "MATHJAX_RELPATH",
              "Cuando MathJax está activado, necesita especificar la ubicación relativa al\n"
              "directorio de salida HTML usando la opción MATHJAX_RELPATH. Para MathJax\n"
              "versión 2, el directorio de destino debe contener el script MathJax.js. Por\n"
              "ejemplo, si el directorio mathjax se encuentra en el mismo nivel que el\n"
              "directorio de salida HTML, entonces MATHJAX_RELPATH debe ser ../mathjax. Para\n"
              "MathJax versiones 3 y 4, el directorio de destino debe contener el script\n"
              "tex-<format>.js (donde <format> es chtml o svg). El valor predeterminado\n"
              "apunta a la Red de Distribución de Contenido de MathJax para que pueda ver\n"
              "rápidamente el resultado sin instalar MathJax. Sin embargo, se recomienda\n"
              "encarecidamente instalar una copia local de MathJax desde\n"
              "https://www.mathjax.org antes de la implementación. El valor predeterminado\n"
              "es:\n"
              "- en caso de MathJax versión 2: https://cdn.jsdelivr.net/npm/mathjax@2\n"
              "- en caso de MathJax versión 3: https://cdn.jsdelivr.net/npm/mathjax@3\n"
              "- en caso de MathJax versión 4: https://cdn.jsdelivr.net/npm/mathjax@4\n"
              "Esta etiqueta requiere que la etiqueta USE_MATHJAX esté establecida en YES."
          );
  doc->add(
              "MATHJAX_EXTENSIONS",
              "La etiqueta MATHJAX_EXTENSIONS se puede usar para especificar uno o más\n"
              "nombres de extensiones MathJax que deben activarse durante el renderizado de\n"
              "MathJax. Por ejemplo para MathJax Versión 2 (vea\n"
              "https://docs.mathjax.org/en/v2.7/tex.html):\n"
              "MATHJAX_EXTENSIONS = TeX/AMSmath TeX/AMSsymbols\n"
              "Por ejemplo para MathJax Versión 3 (vea\n"
              "https://docs.mathjax.org/en/v3.2/input/tex/extensions/):\n"
              "MATHJAX_EXTENSIONS = ams\n"
              "Por ejemplo para MathJax Versión 4 (vea\n"
              "https://docs.mathjax.org/en/v4.0/input/tex/extensions/):\n"
              "MATHJAX_EXTENSIONS = units\n"
              "Tenga en cuenta que para MathJax Versión 4 ya se cargan automáticamente\n"
              "algunas extensiones. Para deshabilitar un paquete en MathJax Versión 4, puede\n"
              "usar el nombre del paquete con un signo menos delante (- como\n"
              "MATHJAX_EXTENSIONS += -textmacros)\n"
              "Esta etiqueta requiere que la etiqueta USE_MATHJAX esté establecida en YES."
          );
  doc->add(
              "MATHJAX_CODEFILE",
              "La etiqueta MATHJAX_CODEFILE se puede usar para especificar un archivo con\n"
              "fragmentos de código JavaScript que se usarán cuando se inicie el código\n"
              "MathJax. Vea el sitio web de MathJax para más detalles:\n"
              "- MathJax versión 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/)\n"
              "- MathJax versión 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/)\n"
              "- MathJax versión 4 (see:\n"
              "https://docs.mathjax.org/en/v4.0/)Para un ejemplo, vea la documentación.\n"
              "Esta etiqueta requiere que la etiqueta USE_MATHJAX esté establecida en YES."
          );
  doc->add(
              "SEARCHENGINE",
              "Cuando la etiqueta SEARCHENGINE está habilitada, Doxygen generará un cuadro de\n"
              "búsqueda para la salida HTML. El motor de búsqueda subyacente usa JavaScript y\n"
              "DHTML y debería funcionar en cualquier navegador moderno. Tenga en cuenta que\n"
              "cuando se usa ayuda HTML (GENERATE_HTMLHELP), ayuda Qt (GENERATE_QHP) o\n"
              "docsets (GENERATE_DOCSET) ya hay una función de búsqueda, por lo que esta\n"
              "debería estar típicamente deshabilitada. Para proyectos grandes, el motor de\n"
              "búsqueda basado en JavaScript puede ser lento, entonces habilitar\n"
              "SERVER_BASED_SEARCH puede proporcionar una mejor solución. Es posible buscar\n"
              "usando el teclado; para saltar al cuadro de búsqueda use <tecla de acceso> + S\n"
              "(cual es la <tecla de acceso> depende del sistema).\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_HTML esté establecida en YES."
          );
  doc->add(
              "SERVER_BASED_SEARCH",
              "Si la etiqueta SERVER_BASED_SEARCH está configurada en YES, el motor de\n"
              "búsqueda se implementa usando un servidor web en lugar de un cliente web. Hay\n"
              "dos formas de configurar esto: usando un script PHP o usando un indexador\n"
              "externo. Vea la sección \"External Indexing and Searching\" para más detalles.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta SEARCHENGINE esté establecida en YES."
          );
  doc->add(
              "EXTERNAL_SEARCH",
              "Si la etiqueta EXTERNAL_SEARCH está habilitada, Doxygen ya no generará el\n"
              "script PHP para buscar. En su lugar, los resultados de búsqueda se escriben en\n"
              "un archivo XML que debe ser procesado por un indexador externo. Doxygen\n"
              "invocará un motor de búsqueda externo especificado por la opción\n"
              "SEARCHENGINE_URL para obtener los resultados de búsqueda.\n"
              "\n"
              "Doxygen proporciona un indexador de ejemplo (doxyindexer) y un motor de\n"
              "búsqueda (doxysearch.cgi) basado en la biblioteca del motor de búsqueda de\n"
              "código abierto Xapian (see:\n"
              "https://xapian.org/).\n"
              "\n"
              "Vea la sección \"External Indexing and Searching\" para más detalles.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta SEARCHENGINE esté establecida en YES."
          );
  doc->add(
              "SEARCHENGINE_URL",
              "Si SERVER_BASED_SEARCH y EXTERNAL_SEARCH están habilitados, la etiqueta\n"
              "SEARCHENGINE_URL se puede usar para especificar una URL a la que enviar una\n"
              "consulta de búsqueda para obtener los resultados de búsqueda. La consulta de\n"
              "búsqueda se anexa a la URL. Para el motor de búsqueda externo, la consulta de\n"
              "búsqueda se envia como un objeto JSON.\n"
              "Esta etiqueta requiere que la etiqueta SEARCHENGINE esté establecida en YES."
          );
  doc->add(
              "SEARCHDATA_FILE",
              "Si SERVER_BASED_SEARCH y EXTERNAL_SEARCH están habilitados, la etiqueta\n"
              "SEARCHDATA_FILE se puede usar para especificar un archivo donde escribir los\n"
              "datos de búsqueda. Si se deja vacío, se usará searchdata.xml.\n"
              "El archivo predeterminado es: searchdata.xml.\n"
              "Esta etiqueta requiere que la etiqueta SEARCHENGINE esté establecida en YES."
          );
  doc->add(
              "EXTERNAL_SEARCH_ID",
              "Si SERVER_BASED_SEARCH y EXTERNAL_SEARCH están habilitados, la etiqueta\n"
              "EXTERNAL_SEARCH_ID se puede usar como identificador para el proyecto. Esto es\n"
              "útil en combinación con EXTRA_SEARCH_MAPPINGS para buscar en múltiples\n"
              "proyectos y dirigir los resultados de vuelta al proyecto correcto.\n"
              "Esta etiqueta requiere que la etiqueta SEARCHENGINE esté establecida en YES."
          );
  doc->add(
              "EXTRA_SEARCH_MAPPINGS",
              "La etiqueta EXTRA_SEARCH_MAPPINGS se puede usar para habilitar la búsqueda en\n"
              "proyectos Doxygen que no están definidos por este archivo de configuración\n"
              "pero que se agregan todos al mismo índice de búsqueda externo. Cada proyecto\n"
              "debe tener una ID única que se establece a través de EXTERNAL_SEARCH_ID. El\n"
              "mapeo de búsqueda luego asigna la ID a una ubicación relativa donde se puede\n"
              "encontrar la documentación. El formato es:\n"
              "EXTRA_SEARCH_MAPPINGS = tagname1=loc1 tagname2=loc2 ...\n"
              "Esta etiqueta requiere que la etiqueta SEARCHENGINE esté establecida en YES."
          );
  doc->add(
              "GENERATE_LATEX",
              "Si la etiqueta GENERATE_LATEX está configurada en YES, Doxygen generará salida\n"
              "LaTeX.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "LATEX_OUTPUT",
              "La etiqueta LATEX_OUTPUT se usa para especificar donde se colocarán los\n"
              "documentos LaTeX. Si se ingresa una ruta relativa, el valor de\n"
              "OUTPUT_DIRECTORY se antepondrá.\n"
              "El directorio predeterminado es: latex.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "LATEX_CMD_NAME",
              "La etiqueta LATEX_CMD_NAME se puede usar para especificar el nombre del\n"
              "comando LaTeX a invocar.\n"
              "\n"
              "Tenga en cuenta que cuando no se habilita USE_PDFLATEX el valor predeterminado\n"
              "es latex, cuando se habilita USE_PDFLATEX el valor predeterminado es pdflatex\n"
              "y cuando en este último caso se elige latex, esto se sobrescribe por pdflatex.\n"
              "Para idiomas de salida específicos, el valor predeterminado puede haberse\n"
              "configurado de manera diferente, esto depende de la implementación del idioma\n"
              "de salida.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "MAKEINDEX_CMD_NAME",
              "La etiqueta MAKEINDEX_CMD_NAME se puede usar para especificar el nombre del\n"
              "comando para generar el índice para LaTeX.\n"
              "Nota: Esta etiqueta se usa en el Makefile / make.bat.\n"
              "Ver también: LATEX_MAKEINDEX_CMD para la parte en el archivo de salida\n"
              "generado (.tex).\n"
              "El archivo predeterminado es: makeindex.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "LATEX_MAKEINDEX_CMD",
              "La etiqueta LATEX_MAKEINDEX_CMD se puede usar para especificar el nombre del\n"
              "comando para generar el índice para LaTeX. Si no hay una barra invertida (\\)\n"
              "como primer carácter, se agregará automáticamente en el código LaTeX.\n"
              "Nota: Esta etiqueta se usa en el archivo de salida generado (.tex).\n"
              "Ver también: MAKEINDEX_CMD_NAME para la parte en el Makefile / make.bat.\n"
              "El valor predeterminado es: makeindex.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "COMPACT_LATEX",
              "Si la etiqueta COMPACT_LATEX está configurada en YES, Doxygen generará\n"
              "documentos LaTeX más compactos. Esto puede ser útil para proyectos pequeños y\n"
              "puede ayudar a ahorrar algunos árboles en general.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "PAPER_TYPE",
              "La etiqueta PAPER_TYPE se puede usar para establecer el tipo de papel que usa\n"
              "la impresora. Los valores posibles son: a4, letter, legal y executive.\n"
              "Los valores posibles son:a4 (210 x 297 mm), letter (8.5 x 11 pulgadas), legal\n"
              "(8.5 x 14 pulgadas)yexecutive (7.25 x 10.5 pulgadas).\n"
              "El valor predeterminado es: a4.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "EXTRA_PACKAGES",
              "La etiqueta EXTRA_PACKAGES se puede usar para especificar uno o más nombres de\n"
              "paquetes LaTeX que se incluirán en la salida LaTeX. El paquete se puede\n"
              "especificar solo por su nombre o con la sintaxis correcta para usar con el\n"
              "comando \\usepackage de LaTeX. Por ejemplo, para obtener la fuente times, puede\n"
              "especificar:\n"
              "EXTRA_PACKAGES=times o EXTRA_PACKAGES={times}\n"
              "Para usar la opción intlimits con el paquete amsmath, puede especificar:\n"
              "EXTRA_PACKAGES=[intlimits]{amsmath}\n"
              "Si se deja vacío, no se incluirán paquetes adicionales.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "LATEX_HEADER",
              "La etiqueta LATEX_HEADER se puede usar para especificar un encabezado LaTeX\n"
              "personalizado para el documento LaTeX generado. El encabezado debe contener\n"
              "todo hasta el primer capítulo. Si se deja vacío, Doxygen generará un\n"
              "encabezado estándar. Se recomienda encarecidamente comenzar con un encabezado\n"
              "estándar usando\n"
              "doxygen -w latex new_header.tex new_footer.tex new_stylesheet.sty\n"
              "y luego modificar el archivo new_header.tex. Vea también la sección \"Doxygen\n"
              "usage\" para información sobre como generar el encabezado estándar que Doxygen\n"
              "normalmente usa.\n"
              "\n"
              "Nota: ¡Solo use un encabezado personalizado si sabe lo que está haciendo!\n"
              "Nota: El encabezado puede cambiar, por lo que generalmente necesita regenerar\n"
              "el encabezado estándar cuando actualiza a una versión más nueva de\n"
              "Doxygen.Para una descripción de los posibles marcadores y nombres de bloques,\n"
              "vea la documentación.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "LATEX_FOOTER",
              "La etiqueta LATEX_FOOTER se puede usar para especificar un pie de página LaTeX\n"
              "personalizado para el documento LaTeX generado. El pie de página debe contener\n"
              "todo después del último capítulo. Si se deja vacío, Doxygen generará un pie de\n"
              "página estándar. Vea LATEX_HEADER para más información sobre como generar un\n"
              "pie de página estándar y que comandos especiales se pueden usar en el pie de\n"
              "página. Vea también la sección \"Doxygen usage\" para información sobre como\n"
              "generar el pie de página estándar que Doxygen normalmente usa. Nota: ¡Solo use\n"
              "un pie de página personalizado si sabe lo que está haciendo!\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "LATEX_EXTRA_STYLESHEET",
              "La etiqueta LATEX_EXTRA_STYLESHEET se puede usar para especificar hojas de\n"
              "estilo LaTeX personalizadas adicionales que se incluirán después de las hojas\n"
              "de estilo estándar creadas por Doxygen. Con esta opción puede anular ciertos\n"
              "aspectos de estilo. Doxygen copiará los archivos de hoja de estilo en el\n"
              "directorio de salida.\n"
              "Nota: El orden de los archivos de hoja de estilo adicionales es importante\n"
              "(por ejemplo, la última hoja de estilo en la lista anula la configuración de\n"
              "las anteriores en la lista).\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "LATEX_EXTRA_FILES",
              "La etiqueta LATEX_EXTRA_FILES se puede usar para especificar una o más\n"
              "imagenes adicionales u otros archivos de origen que deben copiarse en el\n"
              "directorio de salida LATEX_OUTPUT. Tenga en cuenta que los archivos se copian\n"
              "tal como están; no hay comandos o marcadores disponibles.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "PDF_HYPERLINKS",
              "Si la etiqueta PDF_HYPERLINKS está configurada en YES, el LaTeX generado está\n"
              "preparado para la conversión a PDF (usando ps2pdf o pdflatex). El archivo PDF\n"
              "contendrá enlaces (igual que la salida HTML) en lugar de referencias de\n"
              "página. Esto hace que la salida sea adecuada para navegación en línea usando\n"
              "un visor PDF.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "USE_PDFLATEX",
              "Si la etiqueta USE_PDFLATEX está configurada en YES, Doxygen usará el motor\n"
              "especificado con LATEX_CMD_NAME para generar el archivo PDF directamente de\n"
              "los archivos LaTeX. Configure esta opción en YES para obtener documentación\n"
              "PDF de mayor calidad.\n"
              "\n"
              "Vea también la sección LATEX_CMD_NAME para seleccionar el motor.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "LATEX_BATCHMODE",
              "Si la etiqueta LATEX_BATCHMODE está configurada en YES, Doxygen ejecutará el\n"
              "compilador LaTeX en modo por lotes, lo que significa que no se detendrá en\n"
              "errores.\n"
              "Los valores posibles son:NO igual que ERROR_STOP, YES igual que BATCH, BATCH\n"
              "En modo batch no se imprime nada en la terminal, los errores se desplazan como\n"
              "si se presionara <return> en cada error; los archivos faltantes que TeX\n"
              "intenta leer o solicitar desde la entrada del teclado (\\read en un flujo de\n"
              "entrada no abierto) causan que el trabajo se aborte, NON_STOP En modo nonstop\n"
              "el mensaje de diagnóstico aparecerá en la terminal, pero no hay posibilidad de\n"
              "interacción del usuario igual que en modo batch, SCROLL En modo scroll, TeX\n"
              "solo se detendrá para archivos faltantes o si se necesita entrada del\n"
              "tecladoyERROR_STOP En modo errorstop, TeX se detendrá en cada error,\n"
              "solicitando intervención del usuario.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "LATEX_HIDE_INDICES",
              "Si la etiqueta LATEX_HIDE_INDICES está configurada en YES, Doxygen no incluirá\n"
              "los capítulos de índice (como Índice de Archivos, Índice de Compuestos, etc.)\n"
              "en la salida.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "LATEX_BIB_STYLE",
              "La etiqueta LATEX_BIB_STYLE se puede usar para especificar el estilo a usar\n"
              "para la bibliografía, p. ej. plainnat o ieeetr. Vea\n"
              "https://en.wikipedia.org/wiki/BibTeX y \\cite para más información.\n"
              "El valor predeterminado es: plainnat.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "LATEX_EMOJI_DIRECTORY",
              "La etiqueta LATEX_EMOJI_DIRECTORY se usa para especificar la ruta (relativa o\n"
              "absoluta) desde donde se leen las imagenes de emoji. Si se ingresa una ruta\n"
              "relativa, será relativa al directorio LATEX_OUTPUT. Si se deja vacío, se usará\n"
              "el directorio LATEX_OUTPUT.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_LATEX esté establecida en YES."
          );
  doc->add(
              "GENERATE_RTF",
              "Si la etiqueta GENERATE_RTF está configurada en YES, Doxygen generará salida\n"
              "RTF. La salida RTF está optimizada para Word 97 y puede no verse muy bien con\n"
              "otros lectores/editores RTF.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "RTF_OUTPUT",
              "La etiqueta RTF_OUTPUT se usa para especificar donde se colocarán los\n"
              "documentos RTF. Si se ingresa una ruta relativa, el valor de OUTPUT_DIRECTORY\n"
              "se antepondrá.\n"
              "El directorio predeterminado es: rtf.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_RTF esté establecida en YES."
          );
  doc->add(
              "COMPACT_RTF",
              "Si la etiqueta COMPACT_RTF está configurada en YES, Doxygen generará\n"
              "documentos RTF más compactos. Esto puede ser útil para proyectos pequeños y\n"
              "puede ayudar a ahorrar algunos árboles en general.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_RTF esté establecida en YES."
          );
  doc->add(
              "RTF_HYPERLINKS",
              "Si la etiqueta RTF_HYPERLINKS está configurada en YES, el RTF generado\n"
              "contendrá campos de hipervínculo. El archivo RTF contendrá enlaces (igual que\n"
              "la salida HTML) en lugar de referencias de página. Esto hace que la salida sea\n"
              "adecuada para navegación en línea usando Word u otros lectores compatibles con\n"
              "Word que soporten esos campos.\n"
              "\n"
              "Nota: WordPad (write) y otros no soportan enlaces.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_RTF esté establecida en YES."
          );
  doc->add(
              "RTF_STYLESHEET_FILE",
              "Cargue definiciones de hoja de estilo desde un archivo. La sintaxis es similar\n"
              "al archivo de configuración de Doxygen, es decir, una serie de asignaciones.\n"
              "Solo tiene que proporcionar reemplazos, las definiciones faltantes se\n"
              "establecen en su valor predeterminado.\n"
              "\n"
              "Vea también la sección \"Doxygen usage\" para información sobre como generar la\n"
              "hoja de estilo predeterminada que Doxygen normalmente usa.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_RTF esté establecida en YES."
          );
  doc->add(
              "RTF_EXTENSIONS_FILE",
              "Configure variables opcionales usadas en la generación de un documento RTF. La\n"
              "sintaxis es similar al archivo de configuración de Doxygen. Se puede generar\n"
              "un archivo de extensiones de plantilla usando doxygen -e rtf extensionFile.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_RTF esté establecida en YES."
          );
  doc->add(
              "RTF_EXTRA_FILES",
              "La etiqueta RTF_EXTRA_FILES se puede usar para especificar una o más imagenes\n"
              "adicionales u otros archivos de origen que deben copiarse en el directorio de\n"
              "salida RTF. Tenga en cuenta que los archivos se copian tal como están; no hay\n"
              "comandos o marcadores disponibles.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_RTF esté establecida en YES."
          );
  doc->add(
              "GENERATE_MAN",
              "Si la etiqueta GENERATE_MAN está configurada en YES, Doxygen generará páginas\n"
              "de manual para clases y archivos.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "MAN_OUTPUT",
              "La etiqueta MAN_OUTPUT se usa para especificar donde se colocarán las páginas\n"
              "de manual. Si se ingresa una ruta relativa, el valor de OUTPUT_DIRECTORY se\n"
              "antepondrá. Se creará un directorio man3 dentro del directorio especificado\n"
              "por MAN_OUTPUT.\n"
              "El directorio predeterminado es: man.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_MAN esté establecida en YES."
          );
  doc->add(
              "MAN_EXTENSION",
              "La etiqueta MAN_EXTENSION determina la extensión que se agrega a las páginas\n"
              "de manual generadas. Si la sección del manual no comienza con un número, se\n"
              "antepondrá el número 3. El punto (.) al comienzo de la etiqueta MAN_EXTENSION\n"
              "es opcional.\n"
              "El valor predeterminado es: .3.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_MAN esté establecida en YES."
          );
  doc->add(
              "MAN_SUBDIR",
              "La etiqueta MAN_SUBDIR determina el nombre del directorio creado dentro de\n"
              "MAN_OUTPUT donde se colocan las páginas de manual. Por defecto, es man seguido\n"
              "de MAN_EXTENSION sin el . inicial.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_MAN esté establecida en YES."
          );
  doc->add(
              "MAN_LINKS",
              "Si la etiqueta MAN_LINKS está configurada en YES y Doxygen genera salida de\n"
              "manual, generará un archivo de manual adicional para cada entidad documentada\n"
              "en las páginas de manual reales. Estos archivos adicionales solo apuntan a la\n"
              "página de manual real, pero sin ellos, el comando man no podria encontrar la\n"
              "página correcta.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_MAN esté establecida en YES."
          );
  doc->add(
              "GENERATE_XML",
              "Si la etiqueta GENERATE_XML está configurada en YES, Doxygen generará un\n"
              "archivo XML que captura el código y la documentación.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "XML_OUTPUT",
              "La etiqueta XML_OUTPUT se usa para especificar donde se colocarán las páginas\n"
              "XML. Si se ingresa una ruta relativa, el valor de OUTPUT_DIRECTORY se\n"
              "antepondrá.\n"
              "El directorio predeterminado es: xml.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_XML esté establecida en YES."
          );
  doc->add(
              "XML_PROGRAMLISTING",
              "Si la etiqueta XML_PROGRAMLISTING está configurada en YES, Doxygen volcará los\n"
              "listados de programas (incluyendo resaltado de sintaxis e información de\n"
              "referencias cruzadas) a la salida XML. Tenga en cuenta que habilitar esto\n"
              "aumentará significativamente el tamaño de la salida XML.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_XML esté establecida en YES."
          );
  doc->add(
              "XML_NS_MEMB_FILE_SCOPE",
              "Si la etiqueta XML_NS_MEMB_FILE_SCOPE está configurada en YES, Doxygen\n"
              "incluirá miembros de espacios de nombres en el ámbito del archivo también,\n"
              "coincidiendo con la salida HTML.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_XML esté establecida en YES."
          );
  doc->add(
              "GENERATE_DOCBOOK",
              "Si la etiqueta GENERATE_DOCBOOK está configurada en YES, Doxygen generará\n"
              "archivos Docbook que se pueden usar para crear PDF.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "DOCBOOK_OUTPUT",
              "La etiqueta DOCBOOK_OUTPUT se usa para especificar donde se colocarán las\n"
              "páginas Docbook. Si se ingresa una ruta relativa, el valor de OUTPUT_DIRECTORY\n"
              "se antepondrá.\n"
              "El directorio predeterminado es: docbook.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_DOCBOOK esté establecida en\n"
              "YES."
          );
  doc->add(
              "GENERATE_AUTOGEN_DEF",
              "Si la etiqueta GENERATE_AUTOGEN_DEF está configurada en YES, Doxygen generará\n"
              "un archivo de definición AutoGen (vea https://autogen.sourceforge.net/) que\n"
              "captura la estructura del código incluyendo toda la documentación. Tenga en\n"
              "cuenta que esta función es actualmente experimental e incompleta.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "GENERATE_SQLITE3",
              "Si la etiqueta GENERATE_SQLITE3 está configurada en YES, Doxygen generará una\n"
              "base de datos Sqlite3 con símbolos que puede ser usada por el motor de\n"
              "búsqueda.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "SQLITE3_OUTPUT",
              "La etiqueta SQLITE3_OUTPUT se usa para especificar donde se colocará la base\n"
              "de datos Sqlite3. Si se ingresa una ruta relativa, el valor de\n"
              "OUTPUT_DIRECTORY se antepondrá.\n"
              "El directorio predeterminado es: sqlite3.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_SQLITE3 esté establecida en\n"
              "YES."
          );
  doc->add(
              "SQLITE3_RECREATE_DB",
              "Si la etiqueta SQLITE3_RECREATE_DB está configurada en YES, el archivo de base\n"
              "de datos doxygen_sqlite3.db existente se recreará con cada ejecución de\n"
              "Doxygen. Si se configura en NO, Doxygen advertirá si ya se encuentra un\n"
              "archivo de base de datos y no lo modificará.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_SQLITE3 esté establecida en\n"
              "YES."
          );
  doc->add(
              "GENERATE_PERLMOD",
              "Si la etiqueta GENERATE_PERLMOD está configurada en YES, Doxygen generará un\n"
              "archivo de módulo Perl que captura cierta información sobre el código en una\n"
              "forma adecuada para módulos Perl.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "PERLMOD_LATEX",
              "Si la etiqueta PERLMOD_LATEX está configurada en YES, Doxygen generará las\n"
              "reglas necesarias de Makefile, scripts Perl y código LaTeX para poder generar\n"
              "salida PDF y DVI de la salida del módulo Perl.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_PERLMOD esté establecida en\n"
              "YES."
          );
  doc->add(
              "PERLMOD_PRETTY",
              "Si la etiqueta PERLMOD_PRETTY está configurada en YES, la salida del módulo\n"
              "Perl estará formateada de manera agradable para que pueda ser analizada por un\n"
              "lector humano. Esto es útil si desea entender lo que está sucediendo. Por otro\n"
              "lado, si esta etiqueta está configurada en NO, el tamaño de la salida del\n"
              "módulo Perl será mucho más pequeño y Perl lo analizará de la misma manera.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_PERLMOD esté establecida en\n"
              "YES."
          );
  doc->add(
              "PERLMOD_MAKEVAR_PREFIX",
              "Los nombres de las variables make en el archivo doxyrules.make generado tienen\n"
              "como prefijo la cadena contenida en PERLMOD_MAKEVAR_PREFIX. Esto es útil para\n"
              "que diferentes archivos doxyrules.make incluidos por el mismo Makefile no\n"
              "sobrescriban las variables de los demas.\n"
              "Esta etiqueta requiere que la etiqueta GENERATE_PERLMOD esté establecida en\n"
              "YES."
          );
  doc->add(
              "ENABLE_PREPROCESSING",
              "Si la etiqueta ENABLE_PREPROCESSING está configurada en YES, Doxygen evaluara\n"
              "todas las directivas del preprocesador C.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "MACRO_EXPANSION",
              "Si la etiqueta MACRO_EXPANSION está configurada en YES, Doxygen expandirá\n"
              "todos los nombres de macros en el código fuente. Si se configura en NO, solo\n"
              "se realizara la compilación condicional. La expansión de macros se puede\n"
              "controlar configurando EXPAND_ONLY_PREDEF en YES.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta ENABLE_PREPROCESSING esté establecida\n"
              "en YES."
          );
  doc->add(
              "EXPAND_ONLY_PREDEF",
              "Si las etiquetas EXPAND_ONLY_PREDEF y MACRO_EXPANSION están configuradas en\n"
              "YES, la expansión de macros se limita a las macros especificadas con\n"
              "EXPAND_AS_DEFINED.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta ENABLE_PREPROCESSING esté establecida\n"
              "en YES."
          );
  doc->add(
              "SEARCH_INCLUDES",
              "Si la etiqueta SEARCH_INCLUDES está configurada en YES, las dependencias de\n"
              "inclusión se incluyen en la lista de archivos que se buscan.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta ENABLE_PREPROCESSING esté establecida\n"
              "en YES."
          );
  doc->add(
              "INCLUDE_PATH",
              "La etiqueta INCLUDE_PATH se puede usar para especificar uno o más directorios\n"
              "que contienen archivos de inclusión que no son archivos de entrada pero que\n"
              "deben ser procesados por el preprocesador. Tenga en cuenta que INCLUDE_PATH no\n"
              "es recursivo, por lo que configurar RECURSIVE aquí no tendrá efecto.\n"
              "Esta etiqueta requiere que la etiqueta SEARCH_INCLUDES esté establecida en\n"
              "YES."
          );
  doc->add(
              "INCLUDE_FILE_PATTERNS",
              "Puede usar la etiqueta INCLUDE_FILE_PATTERNS para especificar uno o más\n"
              "patrones de comodín (como *.h y *.hpp) para filtrar los archivos de encabezado\n"
              "en los directorios. Si se deja vacío, se usarán los patrones especificados con\n"
              "FILE_PATTERNS.\n"
              "Esta etiqueta requiere que la etiqueta ENABLE_PREPROCESSING esté establecida\n"
              "en YES."
          );
  doc->add(
              "PREDEFINED",
              "La etiqueta PREDEFINED se puede usar para especificar uno o más nombres de\n"
              "macros que se definen antes de que se inicie el preprocesador (similar a la\n"
              "opción -D de, por ejemplo, gcc). El argumento de la etiqueta es una lista de\n"
              "macros de la forma: nombre o nombre=definición (sin espacios). Si se omite la\n"
              "definición y el \"=\", se asume \"=1\". Para evitar que una definición de macro\n"
              "quede indefinida via #undef o se expanda recursivamente, use el operador := en\n"
              "lugar del operador =.\n"
              "Esta etiqueta requiere que la etiqueta ENABLE_PREPROCESSING esté establecida\n"
              "en YES."
          );
  doc->add(
              "EXPAND_AS_DEFINED",
              "Si las etiquetas MACRO_EXPANSION y EXPAND_ONLY_PREDEF están configuradas en\n"
              "YES, esta etiqueta se puede usar para especificar una lista de nombres de\n"
              "macros que deben expandirse. Se usará la definición de macro que se encuentre\n"
              "en el código fuente. Use la etiqueta PREDEFINED si desea usar una definición\n"
              "de macro diferente que anule la definición encontrada en el código fuente.\n"
              "Esta etiqueta requiere que la etiqueta ENABLE_PREPROCESSING esté establecida\n"
              "en YES."
          );
  doc->add(
              "SKIP_FUNCTION_MACROS",
              "Si la etiqueta SKIP_FUNCTION_MACROS está configurada en YES, el preprocesador\n"
              "de Doxygen eliminará todas las referencias a macros similares a funciones que\n"
              "están solas en una línea, tienen un nombre completamente en mayúsculas y no\n"
              "terminan con punto y coma. Estas macros de función se usan típicamente para\n"
              "código repetitivo y confundirán al analizador si no se eliminan.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta ENABLE_PREPROCESSING esté establecida\n"
              "en YES."
          );
  doc->add(
              "TAGFILES",
              "La etiqueta TAGFILES se puede usar para especificar uno o más archivos de\n"
              "etiquetas. Para cada archivo de etiquetas se debe agregar la ubicación de la\n"
              "documentación externa. El formato de un archivo de etiquetas sin esta\n"
              "ubicación es el siguiente:\n"
              "TAGFILES = file1 file2 ...\n"
              "Agregar ubicación para los archivos de etiquetas se hace de la siguiente\n"
              "manera:\n"
              "TAGFILES = file1=loc1 \"file2 = loc2\" ...\n"
              "donde loc1 y loc2 pueden ser rutas relativas o absolutas o URLs. Vea la\n"
              "sección \"Linking to external documentation\" para más información sobre el uso\n"
              "de archivos de etiquetas.\n"
              "Nota: Cada archivo de etiquetas debe tener un nombre único (donde el nombre NO\n"
              "incluye la ruta). Si un archivo de etiquetas no está ubicado en el directorio\n"
              "en el que se ejecuta Doxygen, también debe especificar la ruta al archivo de\n"
              "etiquetas aquí."
          );
  doc->add(
              "GENERATE_TAGFILE",
              "Si se especifica un nombre de archivo después de GENERATE_TAGFILE, Doxygen\n"
              "creará un archivo de etiquetas que puede ser usado por otro proyecto para\n"
              "crear referencias a este proyecto."
          );
  doc->add(
              "ALLEXTERNALS",
              "Si la etiqueta ALLEXTERNALS está configurada en YES, todas las clases externas\n"
              "y espacios de nombres se listarán en los índices de clases y espacios de\n"
              "nombres. Si se configura en NO, solo se listarán las clases externas\n"
              "heredadas.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "EXTERNAL_GROUPS",
              "Si la etiqueta EXTERNAL_GROUPS está configurada en YES, todos los grupos\n"
              "externos se listarán en el índice de temas. Si se configura en NO, solo se\n"
              "listarán los grupos del proyecto actual.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "EXTERNAL_PAGES",
              "Si la etiqueta EXTERNAL_PAGES está configurada en YES, todas las páginas\n"
              "externas se listarán en el índice de páginas relacionadas. Si se configura en\n"
              "NO, solo se listarán las páginas del proyecto actual.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "HIDE_UNDOC_RELATIONS",
              "Si se configura en YES, los grafos de herencia y colaboración ocultarán\n"
              "relaciones de herencia y uso cuando el objetivo no este documentado o no sea\n"
              "una clase.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "HAVE_DOT",
              "Si configura la etiqueta HAVE_DOT en YES, Doxygen asumira que la herramienta\n"
              "dot está disponible en el path. Esta herramienta es parte de Graphviz (see:\n"
              "https://www.graphviz.org/), un kit de herramientas de visualización de grafos\n"
              "de AT&T y Lucent Bell Labs. Las otras opciones en esta sección no tendrán\n"
              "efecto si esta opción está configurada en NO.\n"
              "El valor predeterminado es: NO."
          );
  doc->add(
              "DOT_NUM_THREADS",
              "La etiqueta DOT_NUM_THREADS especifica el número de invocaciones de dot que\n"
              "Doxygen puede ejecutar en paralelo. Cuando se configura en 0, Doxygen lo\n"
              "basará en el número de procesadores disponibles en el sistema. Puede\n"
              "configurarlo explícitamente en un valor mayor que 0 para obtener control sobre\n"
              "el equilibrio entre la carga de la CPU y la velocidad de procesamiento.\n"
              "Valor mínimo: 0, valor máximo: 512, valor predeterminado: 0.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "DOT_BATCH_SIZE",
              "El DOT_BATCH_SIZE especifica el número de gráficos dot que Doxygen puede\n"
              "compilar en una sola invocación de dot. Cuando se establece en 1, Doxygen\n"
              "invocará dot para cada gráfico por separado, lo que puede causar una\n"
              "sobrecarga significativa de creación de procesos, especialmente en sistemas\n"
              "con muchos núcleos de CPU. Junto con DOT_NUM_THREADS, esta configuración se\n"
              "puede utilizar para optimizar la velocidad de procesamiento de dot para un\n"
              "sistema en particular. Doxygen intentará asignar a cada hilo una carga de\n"
              "trabajo equilibrada. Si el número total de gráficos a procesar excede\n"
              "DOT_NUM_THREADS * DOT_BATCH_SIZE, se crearán lotes adicionales para que dot\n"
              "los procese.\n"
              "Valor mínimo: 1, valor máximo: 1000, valor predeterminado: 50.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "DOT_COMMON_ATTR",
              "DOT_COMMON_ATTR son atributos comunes para nodos, aristas y etiquetas de\n"
              "subgrafos. Si desea una fuente diferente en los archivos dot generados por\n"
              "Doxygen, puede especificar los atributos fontname, fontcolor y fontsize. Para\n"
              "detalles, vea <a href=https://graphviz.org/doc/info/attrs.html>Especificación\n"
              "de atributos de nodos, aristas y grafos</a>. Debe asegurarse de que dot pueda\n"
              "encontrar la fuente, lo que se puede lograr colocandola en una ubicación\n"
              "estándar o configurando la variable de entorno DOTFONTPATH o configurando\n"
              "DOT_FONTPATH al directorio que contiene la fuente. El tamaño de fuente\n"
              "predeterminado de graphviz es 14.\n"
              "El valor predeterminado es: fontname=Helvetica,fontsize=10.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "DOT_EDGE_ATTR",
              "DOT_EDGE_ATTR se concatena con DOT_COMMON_ATTR. Para un estilo elegante,\n"
              "puede agregar 'arrowhead=open, arrowtail=open, arrowsize=0.5'. <a\n"
              "href=https://graphviz.org/doc/info/arrows.html>Documentación completa sobre\n"
              "formas de flechas.</a>\n"
              "El valor predeterminado es: labelfontname=Helvetica,labelfontsize=10.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "DOT_NODE_ATTR",
              "DOT_NODE_ATTR se concatena con DOT_COMMON_ATTR. Para una vista sin caja\n"
              "alrededor de los nodos, configure 'shape=plain' o 'shape=plaintext'. <a\n"
              "href=https://www.graphviz.org/doc/info/shapes.html>Especificación de\n"
              "formas</a>\n"
              "El valor predeterminado es: shape=box,height=0.2,width=0.4.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "DOT_FONTPATH",
              "Puede configurar la ruta donde dot puede encontrar la fuente especificada con\n"
              "fontname en DOT_COMMON_ATTR y otros atributos dot.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "CLASS_GRAPH",
              "Si la etiqueta CLASS_GRAPH está configurada en YES o GRAPH o BUILTIN, Doxygen\n"
              "generará un grafo para cada clase documentada que muestre las relaciones de\n"
              "herencia directas e indirectas. Si la etiqueta CLASS_GRAPH está configurada en\n"
              "YES o GRAPH y HAVE_DOT también está habilitado, se usará dot para dibujar el\n"
              "grafo. Si la etiqueta CLASS_GRAPH está configurada en YES y HAVE_DOT está\n"
              "deshabilitado o si la etiqueta CLASS_GRAPH está configurada en BUILTIN, se\n"
              "usará el generador incorporado. Si la etiqueta CLASS_GRAPH está configurada en\n"
              "TEXT, las relaciones de herencia directas e indirectas se mostrarán como\n"
              "texto/enlaces. La activación explícita de un grafo de herencia o la elección\n"
              "de una representación diferente para un grafo de herencia de una clase\n"
              "específica se puede lograr con el comando \\inheritancegraph. La desactivación\n"
              "de un grafo de herencia se puede lograr con el comando \\hideinheritancegraph.\n"
              "Los valores posibles son:NO, YES, TEXT, GRAPHyBUILTIN.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "COLLABORATION_GRAPH",
              "Si la etiqueta COLLABORATION_GRAPH está configurada en YES, Doxygen generará\n"
              "un grafo para cada clase documentada que muestre las dependencias de\n"
              "implementación directas e indirectas (herencia, contención y variables de\n"
              "referencia de clase) de la clase con otras clases documentadas. La activación\n"
              "explícita de un grafo de colaboración cuando COLLABORATION_GRAPH está\n"
              "configurado en NO se puede lograr con el comando \\collaborationgraph. La\n"
              "desactivación de un grafo de colaboración se puede lograr con el comando\n"
              "\\hidecollaborationgraph.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "GROUP_GRAPHS",
              "Si la etiqueta GROUP_GRAPHS está configurada en YES, Doxygen generará un grafo\n"
              "para grupos que muestre las dependencias directas de grupos. La activación\n"
              "explícita de un grafo de dependencia de grupos cuando GROUP_GRAPHS está\n"
              "configurado en NO se puede lograr con el comando \\groupgraph. La desactivación\n"
              "de un grafo de dependencia de grupos se puede lograr con el comando\n"
              "\\hidegroupgraph. Vea también el capítulo Agrupación en el manual.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "UML_LOOK",
              "Si la etiqueta UML_LOOK está configurada en YES, Doxygen generará diagramas de\n"
              "herencia y colaboración en un estilo similar al Lenguaje de Modelado Unificado\n"
              "de OMG.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "UML_LIMIT_NUM_FIELDS",
              "Si la etiqueta UML_LOOK está habilitada, los campos y métodos se muestran\n"
              "dentro del nodo de clase. Si hay muchos campos o métodos y muchos nodos, el\n"
              "grafo puede volverse demasiado grande para ser útil. El umbral\n"
              "UML_LIMIT_NUM_FIELDS limita el número de elementos para cada tipo para hacer\n"
              "el tamaño más manejable. Configure esto en 0 para sin límite. Tenga en cuenta\n"
              "que el umbral puede excederse en un 50% antes de que se aplique el límite. Así\n"
              "que cuando configura el umbral en 10, pueden aparecer hasta 15 campos, pero si\n"
              "el número excede 15, la cantidad total de campos mostrados se limita a 10.\n"
              "Valor mínimo: 0, valor máximo: 100, valor predeterminado: 10.\n"
              "Esta etiqueta requiere que la etiqueta UML_LOOK esté establecida en YES."
          );
  doc->add(
              "UML_MAX_EDGE_LABELS",
              "Si la etiqueta UML_LOOK está habilitada, las etiquetas de campo se muestran a\n"
              "lo largo de la arista entre dos nodos de clase. Si hay muchos campos y muchos\n"
              "nodos, el grafo puede volverse demasiado desordenado. El umbral\n"
              "UML_MAX_EDGE_LABELS limita el número de elementos para hacer el tamaño más\n"
              "manejable. Configure esto en 0 para sin límite.\n"
              "Valor mínimo: 0, valor máximo: 100, valor predeterminado: 10.\n"
              "Esta etiqueta requiere que la etiqueta UML_LOOK esté establecida en YES."
          );
  doc->add(
              "DOT_UML_DETAILS",
              "Si la etiqueta DOT_UML_DETAILS está configurada en NO, Doxygen mostrará\n"
              "atributos y métodos sin tipos y argumentos en los grafos UML. Si la etiqueta\n"
              "DOT_UML_DETAILS está configurada en YES, Doxygen agregará tipo y argumentos\n"
              "para atributos y métodos en los grafos UML. Si la etiqueta DOT_UML_DETAILS\n"
              "está configurada en NONE, Doxygen no generará campos con información de\n"
              "miembros de clase en los grafos UML. Los diagramas de clase se verán similares\n"
              "a los diagramas de clase predeterminados pero usando notación UML para las\n"
              "relaciones.\n"
              "Los valores posibles son:NO, YESyNONE.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta UML_LOOK esté establecida en YES."
          );
  doc->add(
              "DOT_WRAP_THRESHOLD",
              "La etiqueta DOT_WRAP_THRESHOLD se puede usar para establecer el número máximo\n"
              "de caracteres que se mostrarán en una sola línea. Si la longitud de la línea\n"
              "excede este valor significativamente, la línea se dividirá en múltiples\n"
              "líneas. Se aplican algunas heurísticas para evitar saltos de línea poco\n"
              "estéticos.\n"
              "Valor mínimo: 0, valor máximo: 1000, valor predeterminado: 17.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "TEMPLATE_RELATIONS",
              "Si la etiqueta TEMPLATE_RELATIONS está configurada en YES, los grafos de\n"
              "herencia y colaboración mostrarán las relaciones entre plantillas y sus\n"
              "instancias.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "INCLUDE_GRAPH",
              "Si las etiquetas INCLUDE_GRAPH, ENABLE_PREPROCESSING y SEARCH_INCLUDES están\n"
              "configuradas en YES, Doxygen generará un grafo para cada archivo documentado\n"
              "que muestre las dependencias de inclusión directas e indirectas del archivo\n"
              "con otros archivos documentados. La activación explícita de un grafo de\n"
              "inclusión cuando INCLUDE_GRAPH está configurado en NO se puede lograr con el\n"
              "comando \\includegraph. La desactivación de un grafo de inclusión se puede\n"
              "lograr con el comando \\hideincludegraph.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "INCLUDED_BY_GRAPH",
              "Si las etiquetas INCLUDED_BY_GRAPH, ENABLE_PREPROCESSING y SEARCH_INCLUDES\n"
              "están configuradas en YES, Doxygen generará un grafo para cada archivo\n"
              "documentado que muestre las dependencias de inclusión directas e indirectas\n"
              "del archivo con otros archivos documentados. La activación explícita de un\n"
              "grafo de included-by cuando INCLUDED_BY_GRAPH está configurado en NO se puede\n"
              "lograr con el comando \\includedbygraph. La desactivación de un grafo de\n"
              "included-by se puede lograr con el comando \\hideincludedbygraph.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "CALL_GRAPH",
              "Si la etiqueta CALL_GRAPH está configurada en YES, Doxygen generará un grafo\n"
              "de dependencias de llamadas para cada función global o método de clase. Tenga\n"
              "en cuenta que habilitar esta opción aumentará significativamente el tiempo de\n"
              "ejecución. Por lo tanto, en la mayoría de los casos será mejor habilitar\n"
              "grafos de llamadas solo para funciones seleccionadas usando el comando\n"
              "\\callgraph. La desactivación de un grafo de llamadas se puede lograr con el\n"
              "comando \\hidecallgraph.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "CALLER_GRAPH",
              "Si la etiqueta CALLER_GRAPH está configurada en YES, Doxygen generará un grafo\n"
              "de dependencias de llamadores para cada función global o método de clase.\n"
              "Tenga en cuenta que habilitar esta opción aumentará significativamente el\n"
              "tiempo de ejecución. Por lo tanto, en la mayoría de los casos será mejor\n"
              "habilitar grafos de llamadores solo para funciones seleccionadas usando el\n"
              "comando \\callergraph. La desactivación de un grafo de llamadores se puede\n"
              "lograr con el comando \\hidecallergraph.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "GRAPHICAL_HIERARCHY",
              "Si la etiqueta GRAPHICAL_HIERARCHY está configurada en YES, Doxygen mostrará\n"
              "una jerarquía gráfica de todas las clases. Tenga en cuenta que habilitar esta\n"
              "opción requiere que la configuración HAVE_DOT este en YES.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "DIRECTORY_GRAPH",
              "Si la etiqueta DIRECTORY_GRAPH está configurada en YES, Doxygen mostrará las\n"
              "dependencias de un directorio de otros directorios de manera gráfica. Las\n"
              "relaciones de dependencia se determinan por las relaciones #include entre los\n"
              "archivos en los directorios. La activación explícita de un grafo de directorio\n"
              "cuando DIRECTORY_GRAPH está configurado en NO se puede lograr con el comando\n"
              "\\directorygraph. La desactivación de un grafo de directorio se puede lograr\n"
              "con el comando \\hidedirectorygraph.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "DIR_GRAPH_MAX_DEPTH",
              "La etiqueta DIR_GRAPH_MAX_DEPTH se puede usar para limitar el número máximo de\n"
              "niveles de subdirectorios que se generan en los grafos de dependencia de\n"
              "directorios generados por dot.\n"
              "Valor mínimo: 1, valor máximo: 25, valor predeterminado: 1.\n"
              "Esta etiqueta requiere que la etiqueta DIRECTORY_GRAPH esté establecida en\n"
              "YES."
          );
  doc->add(
              "DOT_IMAGE_FORMAT",
              "La etiqueta DOT_IMAGE_FORMAT se puede usar para establecer el formato de\n"
              "imagen de las imagenes generadas por dot. Para una explicación de los formatos\n"
              "de imagen, vea la sección de formatos de salida en la documentación de la\n"
              "herramienta dot (Graphviz (see:\n"
              "https://www.graphviz.org/)).\n"
              "\n"
              "Tenga en cuenta que los formatos svg:cairo y svg:cairo:cairo no se pueden usar\n"
              "en combinación con INTERACTIVE_SVG (INTERACTIVE_SVG se configurará en NO).\n"
              "Los valores posibles son:png, jpg, gif, svg, png:gd, png:gd:gd, png:cairo,\n"
              "png:cairo:gd, png:cairo:cairo, png:cairo:gdiplus, png:gdiplus,\n"
              "png:gdiplus:gdiplus, svg:cairo, svg:cairo:cairo, svg:svg, svg:svg:core,\n"
              "gif:cairo, gif:cairo:gd, gif:cairo:gdiplus, gif:gdiplus, gif:gdiplus:gdiplus,\n"
              "gif:gd, gif:gd:gd, jpg:cairo, jpg:cairo:gd, jpg:cairo:gdiplus, jpg:gd,\n"
              "jpg:gd:gd, jpg:gdiplusyjpg:gdiplus:gdiplus.\n"
              "El valor predeterminado es: png.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "INTERACTIVE_SVG",
              "Si DOT_IMAGE_FORMAT está configurado en svg o svg:svg o svg:svg:core, esta\n"
              "opción se puede configurar en YES para habilitar la generación de imagenes SVG\n"
              "interactivas que permiten zoom y desplazamiento.\n"
              "\n"
              "Tenga en cuenta que esto requiere un navegador moderno que no sea Internet\n"
              "Explorer. Los navegadores probados y funcionales son Firefox, Chrome, Safari y\n"
              "Opera.\n"
              "\n"
              "Tenga en cuenta que esta opción se deshabilita automáticamente cuando\n"
              "DOT_IMAGE_FORMAT está configurado en svg:cairo o svg:cairo:cairo.\n"
              "El valor predeterminado es: NO.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "DOT_PATH",
              "La etiqueta DOT_PATH se puede usar para especificar la ruta donde se puede\n"
              "encontrar la herramienta dot. Si se deja vacío, se asume que dot se encuentra\n"
              "en la ruta de búsqueda predeterminada.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "DOTFILE_DIRS",
              "La etiqueta DOTFILE_DIRS se puede usar para especificar uno o más directorios\n"
              "que contienen archivos dot que se incluyen en la documentación (vea el comando\n"
              "\\dotfile).\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "DIA_PATH",
              "Puede incluir diagramas creados con dia en la documentación de Doxygen.\n"
              "Doxygen ejecutará dia para crear el diagrama e insertarlo en la documentación.\n"
              "La etiqueta DIA_PATH le permite especificar el directorio donde se encuentra\n"
              "el binario de dia. Si se deja vacío, se asume que dia se encuentra en la ruta\n"
              "de búsqueda predeterminada."
          );
  doc->add(
              "DIAFILE_DIRS",
              "La etiqueta DIAFILE_DIRS se puede usar para especificar uno o más directorios\n"
              "que contienen archivos dia que se incluyen en la documentación (vea el comando\n"
              "\\diafile)."
          );
  doc->add(
              "PLANTUML_JAR_PATH",
              "Cuando se usa PlantUML, la etiqueta PLANTUML_JAR_PATH debe usarse para\n"
              "especificar la ruta donde Java puede encontrar el archivo plantuml.jar o el\n"
              "nombre de archivo del archivo jar a usar. Si se deja vacío, se asume que\n"
              "PlantUML no se usa o se llama durante un paso de preprocesamiento. Doxygen\n"
              "generará una advertencia cuando encuentre un comando \\startuml en este caso y\n"
              "no generará salida para el diagrama."
          );
  doc->add(
              "PLANTUML_CFG_FILE",
              "Cuando se usa PlantUML, la etiqueta PLANTUML_CFG_FILE se puede usar para\n"
              "especificar un archivo de configuración para PlantUML."
          );
  doc->add(
              "PLANTUML_INCLUDE_PATH",
              "Cuando se usa PlantUML, las rutas especificadas se buscan para archivos\n"
              "especificados por la declaración !include en un bloque PlantUML."
          );
  doc->add(
              "PLANTUMLFILE_DIRS",
              "La etiqueta PLANTUMLFILE_DIRS se puede usar para especificar uno o más\n"
              "directorios que contienen archivos PlantUml que se incluyen en la\n"
              "documentación (vea el comando \\plantumlfile)."
          );
  doc->add(
              "MERMAID_PATH",
              "Cuando se usan diagramas Mermaid con renderizado CLI, la etiqueta MERMAID_PATH\n"
              "debe usarse para especificar el directorio donde se puede encontrar el\n"
              "ejecutable mmdc (Mermaid CLI). Si se deja vacío, el renderizado basado en CLI\n"
              "está deshabilitado. Para salida HTML, el renderizado del lado del cliente via\n"
              "JavaScript se usa por defecto y no requiere mmdc. Para salida LaTeX/PDF, se\n"
              "requiere mmdc para pre-generar imagenes. Doxygen generará una advertencia\n"
              "cuando se necesite renderizado CLI pero mmdc no este disponible."
          );
  doc->add(
              "MERMAID_CONFIG_FILE",
              "Cuando se usan diagramas Mermaid, la etiqueta MERMAID_CONFIG_FILE se puede\n"
              "usar para especificar un archivo de configuración JSON para la herramienta CLI\n"
              "de Mermaid (mmdc). Este archivo puede contener configuraciones de tema y otras\n"
              "opciones de configuración de Mermaid."
          );
  doc->add(
              "MERMAID_RENDER_MODE",
              "La etiqueta MERMAID_RENDER_MODE controla cómo se renderizan los diagramas\n"
              "Mermaid.\n"
              "Los valores posibles son:AUTO (usar renderizado del lado del cliente para HTML\n"
              "y mmdc para LaTeX/PDF y otros formatos. Si MERMAID_PATH no está configurado,\n"
              "los diagramas no HTML producirán una advertencia), CLI (usar la herramienta\n"
              "mmdc para pregenerar imagenes (requiere Node.js y mermaid-js/mermaid-cli).\n"
              "Funciona para todos los formatos de salida)yCLIENT_SIDE (incrustar mermaid.js\n"
              "en la salida HTML para renderizado del lado del cliente. No requiere mmdc pero\n"
              "solo funciona para salida HTML).\n"
              "El valor predeterminado es: AUTO."
          );
  doc->add(
              "MERMAID_JS_URL",
              "La etiqueta MERMAID_JS_URL especifica la URL desde donde cargar mermaid.js\n"
              "cuando se usa renderizado del lado del cliente (MERMAID_RENDER_MODE es\n"
              "CLIENT_SIDE o AUTO). El valor predeterminado apunta a la última versión de\n"
              "Mermaid v11 en el CDN de jsDelivr.\n"
              "\n"
              "La URL del CDN predeterminada requiere acceso a Internet al ver la\n"
              "documentación generada. Para uso sin conexión, descargue mermaid.esm.min.mjs y\n"
              "configure esto en una ruta relativa, o use MERMAID_RENDER_MODE=CLI para pre-\n"
              "generar imagenes en su lugar.\n"
              "Ejemplos:\n"
              "- Última v11 (predeterminado):\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs/\n"
              "- Versión fijada:\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11.3.0/dist/mermaid.esm.min.mjs/\n"
              "- Copia local: ./mermaid.esm.min.mjs (el usuario debe colocar el archivo en\n"
              "el directorio de salida HTML)\n"
              "El valor predeterminado es:\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs."
          );
  doc->add(
              "MERMAIDFILE_DIRS",
              "La etiqueta MERMAIDFILE_DIRS se puede usar para especificar uno o más\n"
              "directorios que contienen archivos Mermaid que se incluyen en la documentación\n"
              "(vea el comando \\mermaidfile)."
          );
  doc->add(
              "DOT_GRAPH_MAX_NODES",
              "La etiqueta DOT_GRAPH_MAX_NODES se puede usar para establecer el número máximo\n"
              "de nodos que se mostrarán en un grafo. Si el número de nodos en un grafo se\n"
              "vuelve mayor que este valor, Doxygen truncará el grafo, lo cual se visualiza\n"
              "representando un nodo como una caja roja. Tenga en cuenta que el grafo no se\n"
              "mostrará en absoluto si el número de hijos directos del nodo raíz en un grafo\n"
              "ya es mayor que DOT_GRAPH_MAX_NODES. Tenga en cuenta también que el tamaño de\n"
              "un grafo puede estar más limitado por MAX_DOT_GRAPH_DEPTH.\n"
              "Valor mínimo: 0, valor máximo: 10000, valor predeterminado: 50.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "MAX_DOT_GRAPH_DEPTH",
              "La etiqueta MAX_DOT_GRAPH_DEPTH se puede usar para establecer la profundidad\n"
              "máxima de los grafos generados por dot. Un valor de profundidad de 3 significa\n"
              "que solo se mostrarán los nodos que son accesibles desde el nodo raíz a través\n"
              "de una ruta de como máximo 3 aristas. Los nodos que se encuentran más lejos\n"
              "del nodo raíz se omitirán. Tenga en cuenta que configurar esta opción en 1 o 2\n"
              "puede reducir en gran medida el tiempo de computación necesario para bases de\n"
              "código grandes. Tenga en cuenta también que el tamaño de un grafo puede estar\n"
              "más limitado por DOT_GRAPH_MAX_NODES. Usar una profundidad de 0 significa sin\n"
              "límite de profundidad.\n"
              "Valor mínimo: 0, valor máximo: 1000, valor predeterminado: 0.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "GENERATE_LEGEND",
              "Si la etiqueta GENERATE_LEGEND está configurada en YES, Doxygen generará una\n"
              "página de leyenda que explica el significado de los diferentes cuadros en los\n"
              "grafos producidos por dot.\n"
              "Nota: Esta etiqueta requiere que UML_LOOK no esté habilitado, es decir, que se\n"
              "use la representación gráfica interna de Doxygen para los diagramas de\n"
              "herencia y colaboración.\n"
              "El valor predeterminado es: YES.\n"
              "Esta etiqueta requiere que la etiqueta HAVE_DOT esté establecida en YES."
          );
  doc->add(
              "DOT_CLEANUP",
              "Si la etiqueta DOT_CLEANUP está configurada en YES, Doxygen eliminará los\n"
              "archivos intermedios que se usaron para generar los diferentes grafos.\n"
              "\n"
              "Nota: Esta configuración no solo se usa para archivos dot, sino también para\n"
              "archivos temporales msc.\n"
              "El valor predeterminado es: YES."
          );
  doc->add(
              "MSCGEN_TOOL",
              "Puede definir gráficos de secuencia de mensajes dentro de los comentarios de\n"
              "Doxygen usando el comando \\msc. Si la etiqueta MSCGEN_TOOL se deja vacía (el\n"
              "valor predeterminado), Doxygen usará una versión incorporada de la herramienta\n"
              "mscgen para producir los gráficos. Alternativamente, la etiqueta MSCGEN_TOOL\n"
              "también puede especificar el nombre de una herramienta externa. Por ejemplo,\n"
              "especificando prog como valor, Doxygen llamará a la herramienta como prog -T\n"
              "<formato_archivo_salida> -o <archivo_salida> <archivo_entrada>. La herramienta\n"
              "externa debe soportar formatos de archivo de salida \"png\", \"eps\", \"svg\" e\n"
              "\"ismap\"."
          );
  doc->add(
              "MSCFILE_DIRS",
              "La etiqueta MSCFILE_DIRS se puede usar para especificar uno o más directorios\n"
              "que contienen archivos MSC que se incluyen en la documentación (vea el comando\n"
              "\\mscfile)."
          );
}
